% Auto-generated chapter 48 for muslim
% Hadiths in this chapter: 124

\hadithdefcmd{muslim}{6805}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، وَزُهَيْرُ بْنُ حَرْبٍ، - وَاللَّفْظُ لِقُتَيْبَةَ - قَالاَ حَدَّثَنَا جَرِيرٌ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يَقُولُ اللَّهُ عَزَّ وَجَلَّ أَنَا عِنْدَ ظَنِّ عَبْدِي بِي وَأَنَا مَعَهُ حِينَ يَذْكُرُنِي إِنْ ذَكَرَنِي فِي نَفْسِهِ ذَكَرْتُهُ فِي نَفْسِي وَإِنْ ذَكَرَنِي فِي مَلإٍ ذَكَرْتُهُ فِي مَلإٍ هُمْ خَيْرٌ مِنْهُمْ وَإِنْ تَقَرَّبَ مِنِّي شِبْرًا تَقَرَّبْتُ إِلَيْهِ ذِرَاعًا وَإِنْ تَقَرَّبَ إِلَىَّ ذِرَاعًا تَقَرَّبْتُ مِنْهُ بَاعًا وَإِنْ أَتَانِي يَمْشِي أَتَيْتُهُ هَرْوَلَةً ‏"‏ ‏.‏\hadithno{6805}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying that Allah, the Exalted and Glorious, thus stated:I am near to the thought of My servant as he thinks about Me, and I am with him as he remembers Me. And if he remembers Me in his heart, I also remember him in My Heart, and if he remembers Me in assembly I remember him in assembly, better than his (remembrance), and if he draws near Me by the span of a palm, I draw near him by the cubit, and if he draws near Me by the cubit I draw near him by the space (covered by) two hands. And if he walks towards Me, I rush towards him}}
\hadithdefcmd{muslim}{6806}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو كُرَيْبٍ قَالاَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، بِهَذَا الإِسْنَادِ وَلَمْ يَذْكُرْ ‏ "‏ وَإِنْ تَقَرَّبَ إِلَىَّ ذِرَاعًا تَقَرَّبْتُ مِنْهُ بَاعًا ‏"‏ ‏.‏\hadithno{6806}\hadithtrans{This hadith has been narrated on the authority of A'mash with the same chain of transmitters, but there is no mention of these words:" He draws near Me by the space of a hand, I draw near him by the space (covered) by two hands}}
\hadithdefcmd{muslim}{6807}{حَدَّثَنَا مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، حَدَّثَنَا مَعْمَرٌ، عَنْ هَمَّامِ بْنِ مُنَبِّهٍ، قَالَ هَذَا مَا حَدَّثَنَا أَبُو هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم فَذَكَرَ أَحَادِيثَ مِنْهَا وَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ اللَّهَ قَالَ إِذَا تَلَقَّانِي عَبْدِي بِشِبْرٍ تَلَقَّيْتُهُ بِذِرَاعٍ وَإِذَا تَلَقَّانِي بِذِرَاعٍ تَلَقَّيْتُهُ بِبَاعٍ وَإِذَا تَلَقَّانِي بِبَاعٍ أَتَيْتُهُ بِأَسْرَعَ ‏"‏ ‏.‏\hadithno{6807}\hadithtrans{Hammam b. Munabbih reported so many ahadith from Abu Huraira and one out of them is this that Allah's Messenger (ﷺ) said that Allah thus stated:When My servant draws close to me by the span of a palm, I draw close to him by the space of a cubit, and when he draws close to Me by the space of a cubit, I draw close to him by the space (covered) by two hands, and when he draws close to Me by the space (covered by) two hands, I go in hurry towards him}}
\hadithdefcmd{muslim}{6808}{حَدَّثَنَا أُمَيَّةُ بْنُ بِسْطَامَ الْعَيْشِيُّ، حَدَّثَنَا يَزِيدُ، - يَعْنِي ابْنَ زُرَيْعٍ - حَدَّثَنَا رَوْحُ، بْنُ الْقَاسِمِ عَنِ الْعَلاَءِ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَسِيرُ فِي طَرِيقِ مَكَّةَ فَمَرَّ عَلَى جَبَلٍ يُقَالُ لَهُ جُمْدَانُ فَقَالَ ‏"‏ سِيرُوا هَذَا جُمْدَانُ سَبَقَ الْمُفَرِّدُونَ ‏"‏ ‏.‏ قَالُوا وَمَا الْمُفَرِّدُونَ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ الذَّاكِرُونَ اللَّهَ كَثِيرًا وَالذَّاكِرَاتُ ‏"‏ ‏.‏\hadithno{6808}\hadithtrans{Abu Huraira reported that Allah's Messenger (ﷺ) was travelling along the path leading to Mecca that he happened to pass by a mountain called Jumdan. He said:Proceed on, it is Jumdan, Mufarradun have gone ahead. They (the Companions of the Holy Prophet) said: Allah's Messenger, who are Mufarradun? He said: They are those males and females who remember Allah much}}
\hadithdefcmd{muslim}{6809}{حَدَّثَنَا عَمْرٌو النَّاقِدُ، وَزُهَيْرُ بْنُ حَرْبٍ، وَابْنُ أَبِي عُمَرَ، جَمِيعًا عَنْ سُفْيَانَ، - وَاللَّفْظُ لِعَمْرٍو - حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ لِلَّهِ تِسْعَةٌ وَتِسْعُونَ اسْمًا مَنْ حَفِظَهَا دَخَلَ الْجَنَّةَ وَإِنَّ اللَّهَ وِتْرٌ يُحِبُّ الْوِتْرَ ‏"‏ ‏.‏ وَفِي رِوَايَةِ ابْنِ أَبِي عُمَرَ ‏"‏ مَنْ أَحْصَاهَا ‏"‏ ‏.‏\hadithno{6809}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:There are ninety-nine names of Allah; he who commits them to memory would get into Paradise. Verily, Allah is Odd (He is one, and it is an odd number) and He loves odd number. And in the narration of Ibn 'Umar (the words are):" He who enumerated them}}
\hadithdefcmd{muslim}{6810}{حَدَّثَنِي مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، حَدَّثَنَا مَعْمَرٌ، عَنْ أَيُّوبَ، عَنِ ابْنِ سِيرِينَ، عَنْ أَبِي هُرَيْرَةَ، وَعَنْ هَمَّامِ بْنِ مُنَبِّهٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ إِنَّ لِلَّهِ تِسْعَةً وَتِسْعِينَ اسْمًا مِائَةً إِلاَّ وَاحِدًا مَنْ أَحْصَاهَا دَخَلَ الْجَنَّةَ ‏"‏ ‏.‏ وَزَادَ هَمَّامٌ عَنْ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏"‏ إِنَّهُ وِتْرٌ يُحِبُّ الْوِتْرَ ‏"‏ ‏.‏\hadithno{6810}\hadithtrans{Abu Huraira reported Allah's Apostle (ﷺ) as saying:Verily, there are ninety-nine names for Allah, i. e. hundred excepting one. He who enumerates them would get into Paradise. And Hammam has made this addition on the authority of Abu Huraira who reported it from Allah's Apostle (ﷺ) that he said:" He is Odd (one) and loves odd number}}
\hadithdefcmd{muslim}{6811}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَزُهَيْرُ بْنُ حَرْبٍ، جَمِيعًا عَنِ ابْنِ عُلَيَّةَ، قَالَ أَبُو بَكْرٍ حَدَّثَنَا إِسْمَاعِيلُ ابْنُ عُلَيَّةَ، عَنْ عَبْدِ الْعَزِيزِ بْنِ صُهَيْبٍ، عَنْ أَنَسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا دَعَا أَحَدُكُمْ فَلْيَعْزِمْ فِي الدُّعَاءِ وَلاَ يَقُلِ اللَّهُمَّ إِنْ شِئْتَ فَأَعْطِنِي فَإِنَّ اللَّهَ لاَ مُسْتَكْرِهَ لَهُ ‏"‏ ‏.‏\hadithno{6811}\hadithtrans{Anas reported Allah's Messenger (ﷺ) as saying:When one of you makes supplication, he should supplicate with a will and should not say: O Allah, confer upon me if Thou likest, for there is none to coerce Allah}}
\hadithdefcmd{muslim}{6812}{حَدَّثَنَا يَحْيَى بْنُ أَيُّوبَ، وَقُتَيْبَةُ، وَابْنُ، حُجْرٍ قَالُوا حَدَّثَنَا إِسْمَاعِيلُ، - يَعْنُونَ ابْنَ جَعْفَرٍ - عَنِ الْعَلاَءِ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا دَعَا أَحَدُكُمْ فَلاَ يَقُلِ اللَّهُمَّ اغْفِرْ لِي إِنْ شِئْتَ وَلَكِنْ لِيَعْزِمِ الْمَسْأَلَةَ وَلْيُعَظِّمِ الرَّغْبَةَ فَإِنَّ اللَّهَ لاَ يَتَعَاظَمُهُ شَىْءٌ أَعْطَاهُ ‏"‏ ‏.‏\hadithno{6812}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:When one of you makes a supplication (to his Lord) one should not say: O Allah, grant me pardon, if Thou so likest, but one should beg one's (Lord) with a will and full devotion, for there is nothing so great in the eye of Allah which He cannot grant}}
\hadithdefcmd{muslim}{6813}{حَدَّثَنَا إِسْحَاقُ بْنُ مُوسَى الأَنْصَارِيُّ، حَدَّثَنَا أَنَسُ بْنُ عِيَاضٍ، حَدَّثَنَا الْحَارِثُ، - وَهُوَ ابْنُ عَبْدِ الرَّحْمَنِ بْنِ أَبِي ذُبَابٍ - عَنْ عَطَاءِ بْنِ مِينَاءَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ لاَ يَقُولَنَّ أَحَدُكُمُ اللَّهُمَّ اغْفِرْ لِي إِنْ شِئْتَ اللَّهُمَّ ارْحَمْنِي إِنْ شِئْتَ ‏.‏ لِيَعْزِمْ فِي الدُّعَاءِ فَإِنَّ اللَّهَ صَانِعٌ مَا شَاءَ لاَ مُكْرِهَ لَهُ ‏"‏ ‏.‏\hadithno{6813}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:None of you should say to Allah (like this): O Allah, grant me mercy, if thou so likest. The supplication (of his) should (be permeated with) conviction (that it would be accepted by the Lord), for Allah is the Doer of (everything) He likes to do, and there is none to force Him (to do or not to do this or that)}}
\hadithdefcmd{muslim}{6814}{حَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا إِسْمَاعِيلُ، - يَعْنِي ابْنَ عُلَيَّةَ - عَنْ عَبْدِ الْعَزِيزِ، عَنْ أَنَسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ يَتَمَنَّيَنَّ أَحَدُكُمُ الْمَوْتَ لِضُرٍّ نَزَلَ بِهِ فَإِنْ كَانَ لاَ بُدَّ مُتَمَنِّيًا فَلْيَقُلِ اللَّهُمَّ أَحْيِنِي مَا كَانَتِ الْحَيَاةُ خَيْرًا لِي وَتَوَفَّنِي إِذَا كَانَتِ الْوَفَاةُ خَيْرًا لِي ‏"‏ ‏.‏\hadithno{6814}\hadithtrans{Anas (b. Malik) reported Allah's Messenger (ﷺ) as saying. None of you should make a request for death because of the trouble in which he is involved, but if there is no other help to it, then say:O Allah, keep me alive as long as there is goodness in life for me and bring death to me when there is goodness in death for me}}
\hadithdefcmd{muslim}{6815}{حَدَّثَنَا ابْنُ أَبِي خَلَفٍ، حَدَّثَنَا رَوْحٌ، حَدَّثَنَا شُعْبَةُ، ح وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا عَفَّانُ، حَدَّثَنَا حَمَّادٌ، - يَعْنِي ابْنَ سَلَمَةَ - كِلاَهُمَا عَنْ ثَابِتٍ، عَنْ أَنَسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمِثْلِهِ غَيْرَ أَنَّهُ قَالَ ‏ "‏ مِنْ ضُرٍّ أَصَابَهُ ‏"‏ ‏.‏\hadithno{6815}\hadithtrans{This hadith has been narrated on the authority of Anas through another chain of transmitters, but with a small variation of wording}}
\hadithdefcmd{muslim}{6816}{حَدَّثَنِي حَامِدُ بْنُ عُمَرَ، حَدَّثَنَا عَبْدُ الْوَاحِدِ، حَدَّثَنَا عَاصِمٌ، عَنِ النَّضْرِ بْنِ أَنَسٍ، وَأَنَسٌ، يَوْمَئِذٍ حَىٌّ قَالَ أَنَسٌ لَوْلاَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَتَمَنَّيَنَّ أَحَدُكُمُ الْمَوْتَ ‏"‏ ‏.‏ لَتَمَنَّيْتُهُ ‏.‏\hadithno{6816}\hadithtrans{Nadr b. Anas reported, as when Anas was alive, that he said:Had Allah's Messenger (ﷺ) not stated this.." None should make a request for death," I would have definitely done that}}
\hadithdefcmd{muslim}{6817}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ إِدْرِيسَ، عَنْ إِسْمَاعِيلَ بْنِ أَبِي، خَالِدٍ عَنْ قَيْسِ بْنِ أَبِي حَازِمٍ، قَالَ دَخَلْنَا عَلَى خَبَّابٍ وَقَدِ اكْتَوَى سَبْعَ كَيَّاتٍ فِي بَطْنِهِ فَقَالَ لَوْمَا أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَانَا أَنْ نَدْعُوَ بِالْمَوْتِ لَدَعَوْتُ بِهِ ‏.‏\hadithno{6817}\hadithtrans{Abu Hazim reported:I visited Khabbab who had seven cauteries on his stomach and he said: Had Allah's Messenger (ﷺ) not forbidden us to call for death, I would have done so}}
\hadithdefcmd{muslim}{6818}{حَدَّثَنَاهُ إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، وَجَرِيرُ بْنُ عَبْدِ الْحَمِيدِ، وَوَكِيعٌ ح وَحَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا أَبِي ح، وَحَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، وَيَحْيَى بْنُ حَبِيبٍ، قَالاَ حَدَّثَنَا مُعْتَمِرٌ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا أَبُو أُسَامَةَ، كُلُّهُمْ عَنْ إِسْمَاعِيلَ، بِهَذَا الإِسْنَادِ ‏.‏\hadithno{6818}\hadithtrans{This hadith has been transmitted on the authority of Isma'il through other chains of narrators}}
\hadithdefcmd{muslim}{6819}{حَدَّثَنَا مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنْ هَمَّامِ بْنِ مُنَبِّهٍ، قَالَ هَذَا مَا حَدَّثَنَا أَبُو هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم فَذَكَرَ أَحَادِيثَ مِنْهَا وَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ يَتَمَنَّى أَحَدُكُمُ الْمَوْتَ وَلاَ يَدْعُ بِهِ مِنْ قَبْلِ أَنْ يَأْتِيَهُ إِنَّهُ إِذَا مَاتَ أَحَدُكُمُ انْقَطَعَ عَمَلُهُ وَإِنَّهُ لاَ يَزِيدُ الْمُؤْمِنَ عُمْرُهُ إِلاَّ خَيْرًا ‏"‏ ‏.‏\hadithno{6819}\hadithtrans{Hammam b. Munabbih said:Abu Huraira narrated to us ahadith from Allah's Messenger (ﷺ) and out of these one is that Allah's Messenger (ﷺ) said: None amongst you should make a request for death, and do not call for it before it comes, for when any one of you dies, he ceases (to do good) deeds and the life of a believer is not prolonged but for goodness}}
\hadithdefcmd{muslim}{6820}{حَدَّثَنَا هَدَّابُ بْنُ خَالِدٍ، حَدَّثَنَا هَمَّامٌ، حَدَّثَنَا قَتَادَةُ، عَنْ أَنَسِ بْنِ مَالِكٍ، عَنْ عُبَادَةَ، بْنِ الصَّامِتِ أَنَّ نَبِيَّ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ أَحَبَّ لِقَاءَ اللَّهِ أَحَبَّ اللَّهُ لِقَاءَهُ وَمَنْ كَرِهَ لِقَاءَ اللَّهِ كَرِهَ اللَّهُ لِقَاءَهُ ‏"‏ ‏.‏\hadithno{6820}\hadithtrans{Ubida b. Samit reported Allah's Messenger (ﷺ) as saying:He who loves to meet Allah, Allah also loves to meet him, and he who dislikes to meet Allah, Allah also abhors to meet him}}
\hadithdefcmd{muslim}{6821}{وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، قَالَ سَمِعْتُ أَنَسَ بْنَ مَالِكٍ، يُحَدِّثُ عَنْ عُبَادَةَ بْنِ الصَّامِتِ، عَنِ النَّبِيِّ صلى الله عليه وسلم مِثْلَهُ ‏.‏\hadithno{6821}\hadithtrans{This hadith has been narrated on the authority of 'Ubada b. Samit through another chain of transmitters}}
\hadithdefcmd{muslim}{6822}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ الرُّزِّيُّ، حَدَّثَنَا خَالِدُ بْنُ الْحَارِثِ الْهُجَيْمِيُّ، حَدَّثَنَا سَعِيدٌ، عَنْ قَتَادَةَ، عَنْ زُرَارَةَ، عَنْ سَعْدِ بْنِ هِشَامٍ، عَنْ عَائِشَةَ، قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنْ أَحَبَّ لِقَاءَ اللَّهِ أَحَبَّ اللَّهُ لِقَاءَهُ وَمَنْ كَرِهَ لِقَاءَ اللَّهِ كَرِهَ اللَّهُ لِقَاءَهُ ‏"‏ ‏.‏ فَقُلْتُ يَا نَبِيَّ اللَّهِ أَكَرَاهِيَةُ الْمَوْتِ فَكُلُّنَا نَكْرَهُ الْمَوْتَ فَقَالَ ‏"‏ لَيْسَ كَذَلِكِ وَلَكِنَّ الْمُؤْمِنَ إِذَا بُشِّرَ بِرَحْمَةِ اللَّهِ وَرِضْوَانِهِ وَجَنَّتِهِ أَحَبَّ لِقَاءَ اللَّهِ فَأَحَبَّ اللَّهُ لِقَاءَهُ وَإِنَّ الْكَافِرَ إِذَا بُشِّرَ بِعَذَابِ اللَّهِ وَسَخَطِهِ كَرِهَ لِقَاءَ اللَّهِ وَكَرِهَ اللَّهُ لِقَاءَهُ ‏"‏ ‏.‏\hadithno{6822}\hadithtrans{A'isha reported that Allah's Messenger (ﷺ) said:He who loves to meet Allah, Allah loves to meet him, and he who dislikes to meet Allah, Allah abhors to meet him. I ('A'isha) said: Allah's Apostle, so far as the feeling of aversion against death is concerned, we all have this feeling. Thereupon he (the Holy Prophet) said: It is not that (which you construe), but (this) that when a believer (at the time of death) is given the glad tidings of the mercy of Allah, His Pleasure, and of Paradise, he loves to meet Allah, and Allah also loves to meet him, and when an unbeliever is given the news of the torment at the Hand of Allah, and Hardship to be imposed by Him, he dislikes to meet Allah and Allah also abhors to meet him}}
\hadithdefcmd{muslim}{6823}{حَدَّثَنَاهُ مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدُ بْنُ بَكْرٍ، حَدَّثَنَا سَعِيدٌ، عَنْ قَتَادَةَ، بِهَذَا الإِسْنَادِ ‏.‏\hadithno{6823}\hadithtrans{This hadith has been reported on the authority of Qatida with the same chain of transmitters}}
\hadithdefcmd{muslim}{6824}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، عَنْ زَكَرِيَّاءَ، عَنِ الشَّعْبِيِّ، عَنْ شُرَيْحِ بْنِ هَانِئٍ، عَنْ عَائِشَةَ، قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ أَحَبَّ لِقَاءَ اللَّهِ أَحَبَّ اللَّهُ لِقَاءَهُ وَمَنْ كَرِهَ لِقَاءَ اللَّهِ كَرِهَ اللَّهُ لِقَاءَهُ وَالْمَوْتُ قَبْلَ لِقَاءِ اللَّهِ ‏"‏ ‏.‏\hadithno{6824}\hadithtrans{A'isha reported Allah's Messenger (ﷺ) as saying:He who loves to meet Allah, Allah also loves to meet him, and who dislikes to meet Allah, Allah abhors to meet him. There is death before (one is able to) meet Allah}}
\hadithdefcmd{muslim}{6825}{حَدَّثَنَاهُ إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا عِيسَى بْنُ يُونُسَ، حَدَّثَنَا زَكَرِيَّاءُ، عَنْ عَامِرٍ، حَدَّثَنِي شُرَيْحُ بْنُ هَانِئٍ، أَنَّ عَائِشَةَ، أَخْبَرَتْهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ بِمِثْلِهِ ‏.‏\hadithno{6825}\hadithtrans{A hadith like this has been narrated on the authority of A'isha through another chain of transmitters}}
\hadithdefcmd{muslim}{6826}{حَدَّثَنَا سَعِيدُ بْنُ عَمْرٍو الأَشْعَثِيُّ، أَخْبَرَنَا عَبْثَرٌ، عَنْ مُطَرِّفٍ، عَنْ عَامِرٍ، عَنْ شُرَيْحِ، بْنِ هَانِئٍ عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنْ أَحَبَّ لِقَاءَ اللَّهِ أَحَبَّ اللَّهُ لِقَاءَهُ وَمَنْ كَرِهَ لِقَاءَ اللَّهِ كَرِهَ اللَّهُ لِقَاءَهُ ‏"‏ ‏.‏ قَالَ فَأَتَيْتُ عَائِشَةَ فَقُلْتُ يَا أُمَّ الْمُؤْمِنِينَ سَمِعْتُ أَبَا هُرَيْرَةَ يَذْكُرُ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم حَدِيثًا إِنْ كَانَ كَذَلِكَ فَقَدْ هَلَكْنَا ‏.‏ فَقَالَتْ إِنَّ الْهَالِكَ مَنْ هَلَكَ بِقَوْلِ رَسُولِ اللَّهِ صلى الله عليه وسلم وَمَا ذَاكَ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنْ أَحَبَّ لِقَاءَ اللَّهِ أَحَبَّ اللَّهُ لِقَاءَهُ وَمَنْ كَرِهَ لِقَاءَ اللَّهِ كَرِهَ اللَّهُ لِقَاءَهُ ‏"‏ ‏.‏ وَلَيْسَ مِنَّا أَحَدٌ إِلاَّ وَهُوَ يَكْرَهُ الْمَوْتَ ‏.‏ فَقَالَتْ قَدْ قَالَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم وَلَيْسَ بِالَّذِي تَذْهَبُ إِلَيْهِ وَلَكِنْ إِذَا شَخَصَ الْبَصَرُ وَحَشْرَجَ الصَّدْرُ وَاقْشَعَرَّ الْجِلْدُ وَتَشَنَّجَتِ الأَصَابِعُ فَعِنْدَ ذَلِكَ مَنْ أَحَبَّ لِقَاءَ اللَّهِ أَحَبَّ اللَّهُ لِقَاءَهُ وَمَنْ كَرِهَ لِقَاءَ اللَّهِ كَرِهَ اللَّهُ لِقَاءَهُ ‏.‏\hadithno{6826}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:He who loves meeting Allah, Allah loves to meet him, and he who dislikes to meet Allah, Allah abhors to meet him. I (Shuraih b. Hani, one of the narrators) came to A'isha and said to her: Mother of the faithful, I heard Abu Huraira narrate from Allah's Messenger (ﷺ) which, if it is actually so, is a destruction to us. Thereupon she said: Those are in fact ruined who are ruined at the words of Allah's Messenger (ﷺ). What are (the words which in your opinion would cause your destruction)? He said that Allah's Messenger (ﷺ) had stated: He who loves to meet Allah, Allah too loves to meet him, and he who dislikes to meet Allah, Allah too abhors to meet him, and there is none amongst us who dons not hate death. Thereupon she said: Allah's Messenger (ﷺ) has in fact stated this, but it does not mean what you construe, but it implies (the time) when one loses the lustre of the eye, and there is rattling in the throat, shudder in the body and convulsion in fingers (at the time of death). (It is about this time) that it has been said: He who loves to meet Allah, Allah would love to meet him, and he who dislikes to meet Allah, Allah would abhor to meet him}}
\hadithdefcmd{muslim}{6827}{وَحَدَّثَنَاهُ إِسْحَاقُ بْنُ إِبْرَاهِيمَ الْحَنْظَلِيُّ، أَخْبَرَنِي جَرِيرٌ، عَنْ مُطَرِّفٍ، بِهَذَا الإِسْنَادِ نَحْوَ حَدِيثِ عَبْثَرٍ ‏.‏\hadithno{6827}\hadithtrans{This hadith has been reported on the authority of Mutarrif with the same chain of transmitters}}
\hadithdefcmd{muslim}{6828}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو عَامِرٍ الأَشْعَرِيُّ وَأَبُو كُرَيْبٍ قَالُوا حَدَّثَنَا أَبُو أُسَامَةَ عَنْ بُرَيْدٍ، عَنْ أَبِي بُرْدَةَ، عَنْ أَبِي مُوسَى، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ أَحَبَّ لِقَاءَ اللَّهِ أَحَبَّ اللَّهُ لِقَاءَهُ وَمَنْ كَرِهَ لِقَاءَ اللَّهِ كَرِهَ اللَّهُ لِقَاءَهُ ‏"‏ ‏.‏\hadithno{6828}\hadithtrans{Abu Musa reported Allah's Apostle (ﷺ) as saying:He who loves to meet Allah, Allah too loves to meet him, and he who dislikes to meet Allah, Allah abhors to meet him}}
\hadithdefcmd{muslim}{6829}{حَدَّثَنَا أَبُو كُرَيْبٍ، مُحَمَّدُ بْنُ الْعَلاَءِ حَدَّثَنَا وَكِيعٌ، عَنْ جَعْفَرِ بْنِ بُرْقَانَ، عَنْ يَزِيدَ، بْنِ الأَصَمِّ عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ اللَّهَ يَقُولُ أَنَا عِنْدَ ظَنِّ عَبْدِي بِي وَأَنَا مَعَهُ إِذَا دَعَانِي ‏"‏ ‏.‏\hadithno{6829}\hadithtrans{Abu Huraira reported Allah's Messenger (may peace be upon him as saying that Allah thus stated:I live in the thought of My servant as he thinks of Me and with him as he calls Me)}}
\hadithdefcmd{muslim}{6830}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارِ بْنِ عُثْمَانَ الْعَبْدِيُّ، حَدَّثَنَا يَحْيَى، - يَعْنِي ابْنَ سَعِيدٍ - وَابْنُ أَبِي عَدِيٍّ عَنْ سُلَيْمَانَ، - وَهُوَ التَّيْمِيُّ - عَنْ أَنَسِ بْنِ مَالِكٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ قَالَ اللَّهُ عَزَّ وَجَلَّ إِذَا تَقَرَّبَ عَبْدِي مِنِّي شِبْرًا تَقَرَّبْتُ مِنْهُ ذِرَاعًا وَإِذَا تَقَرَّبَ مِنِّي ذِرَاعًا تَقَرَّبْتُ مِنْهُ بَاعًا - أَوْ بُوعًا - وَإِذَا أَتَانِي يَمْشِي أَتَيْتُهُ هَرْوَلَةً ‏"‏ ‏.‏\hadithno{6830}\hadithtrans{Abu Huraira reported Allah's Apostle (ﷺ) as saying that Allah, the Exalted and Glorious, said:When My servant draws close to Me by the span of a palm, I draw close to him by the cubit and when he draws close to Me by the cubit, I draw close to him by the space (covered) by two armspans, and when he comes to me walking, I go in a hurry towards him}}
\hadithdefcmd{muslim}{6831}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى الْقَيْسِيُّ، حَدَّثَنَا مُعْتَمِرٌ، عَنْ أَبِيهِ، بِهَذَا الإِسْنَادِ وَلَمْ يَذْكُرْ ‏ "‏ إِذَا أَتَانِي يَمْشِي أَتَيْتُهُ هَرْوَلَةً ‏"‏ ‏.‏\hadithno{6831}\hadithtrans{This hadith has been narrated on the authority of Mu'tamar from his father with the same chain of transmitters, with a slight variation of wording}}
\hadithdefcmd{muslim}{6832}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو كُرَيْبٍ - وَاللَّفْظُ لأَبِي كُرَيْبٍ - قَالاَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يَقُولُ اللَّهُ عَزَّ وَجَلَّ أَنَا عِنْدَ ظَنِّ عَبْدِي وَأَنَا مَعَهُ حِينَ يَذْكُرُنِي فَإِنْ ذَكَرَنِي فِي نَفْسِهِ ذَكَرْتُهُ فِي نَفْسِي وَإِنْ ذَكَرَنِي فِي مَلإٍ ذَكَرْتُهُ فِي مَلإٍ خَيْرٍ مِنْهُ وَإِنِ اقْتَرَبَ إِلَىَّ شِبْرًا تَقَرَّبْتُ إِلَيْهِ ذِرَاعًا وَإِنِ اقْتَرَبَ إِلَىَّ ذِرَاعًا اقْتَرَبْتُ إِلَيْهِ بَاعًا وَإِنْ أَتَانِي يَمْشِي أَتَيْتُهُ هَرْوَلَةً ‏"‏ ‏.‏\hadithno{6832}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying that Allah, the Exalted and Glorious, thus stated:I live in the thought of My servant as he thinks about Me, and I am with him, as he remembers Me. And if he remembers Me in his heart, I also remember him in My Heart, and if he remembers Me in assembly I remember him in the assembly, better than he (does that), and if he draws near Me by the span of a palm I draw near him by the cubit, and if he draws near Me by the cubit I draw near him by the space (covered by) two hands. And if he walks towards Me, I rush towards him}}
\hadithdefcmd{muslim}{6833}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا الأَعْمَشُ، عَنِ الْمَعْرُورِ بْنِ سُوَيْدٍ، عَنْ أَبِي ذَرٍّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يَقُولُ اللَّهُ عَزَّ وَجَلَّ مَنْ جَاءَ بِالْحَسَنَةِ فَلَهُ عَشْرُ أَمْثَالِهَا وَأَزِيدُ وَمَنْ جَاءَ بِالسَّيِّئَةِ فَجَزَاؤُهُ سَيِّئَةٌ مِثْلُهَا أَوْ أَغْفِرُ وَمَنْ تَقَرَّبَ مِنِّي شِبْرًا تَقَرَّبْتُ مِنْهُ ذِرَاعًا وَمَنْ تَقَرَّبَ مِنِّي ذِرَاعًا تَقَرَّبْتُ مِنْهُ بَاعًا وَمَنْ أَتَانِي يَمْشِي أَتَيْتُهُ هَرْوَلَةً وَمَنْ لَقِيَنِي بِقُرَابِ الأَرْضِ خَطِيئَةً لاَ يُشْرِكُ بِي شَيْئًا لَقِيتُهُ بِمِثْلِهَا مَغْفِرَةً ‏"‏ ‏.‏ قَالَ إِبْرَاهِيمُ حَدَّثَنَا الْحَسَنُ بْنُ بِشْرٍ حَدَّثَنَا وَكِيعٌ بِهَذَا الْحَدِيثِ ‏.‏\hadithno{6833}\hadithtrans{Abu Dharr reported Allah's Messenger (ﷺ) as saying that Allah, the Exalted and Glorious, stated:" He who comes with goodness, there are in store for him ten like those and even more than those: 'And he who comes with vice, ' it is only for that that he is called to account. I even forgive him (as I like) and he who draws close to Me by the span of a palm I draw close to him by the cubit, and he who draws close to Me by the cubit I draw close to him by the space (covered) by two hands, and he who walks towards Me I rush towards him, and he who meets Me in the state that his sins fill the earth, but not associating anything with Me, I would meet Him with the same (vastness) of pardon (on My behalf)." This hadith has been transmitted on the authority of Waki}}
\hadithdefcmd{muslim}{6834}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، بِهَذَا الإِسْنَادِ ‏.‏ نَحْوَهُ غَيْرَ أَنَّهُ قَالَ ‏ "‏ فَلَهُ عَشْرُ أَمْثَالِهَا أَوْ أَزِيدُ ‏"‏ ‏.‏\hadithno{6834}\hadithtrans{A hadith like this has been transmitted on the authority of A'mash with the same chain of transmitters and he (further) said:There is for him ten like that (the good he performed) or more than that}}
\hadithdefcmd{muslim}{6835}{حَدَّثَنَا أَبُو الْخَطَّابِ، زِيَادُ بْنُ يَحْيَى الْحَسَّانِيُّ حَدَّثَنَا مُحَمَّدُ بْنُ أَبِي عَدِيٍّ، عَنْ حُمَيْدٍ، عَنْ ثَابِتٍ، عَنْ أَنَسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم عَادَ رَجُلاً مِنَ الْمُسْلِمِينَ قَدْ خَفَتَ فَصَارَ مِثْلَ الْفَرْخِ فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ هَلْ كُنْتَ تَدْعُو بِشَىْءٍ أَوْ تَسْأَلُهُ إِيَّاهُ ‏"‏ ‏.‏ قَالَ نَعَمْ كُنْتُ أَقُولُ اللَّهُمَّ مَا كُنْتَ مُعَاقِبِي بِهِ فِي الآخِرَةِ فَعَجِّلْهُ لِي فِي الدُّنْيَا ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ سُبْحَانَ اللَّهِ لاَ تُطِيقُهُ - أَوْ لاَ تَسْتَطِيعُهُ - أَفَلاَ قُلْتَ اللَّهُمَّ آتِنَا فِي الدُّنْيَا حَسَنَةً وَفِي الآخِرَةِ حَسَنَةً وَقِنَا عَذَابَ النَّارِ ‏"‏ ‏.‏ قَالَ فَدَعَا اللَّهَ لَهُ فَشَفَاهُ ‏.‏\hadithno{6835}\hadithtrans{Anas reported that Allah's Messenger (ﷺ) visited a person from amongst the Muslims in order to inquire (about his health) who had grown feeble like the chicken. Allah's Messenger (ﷺ) said:Did you supplicate for anything or beg of Him about that? He said: Yes. I used to utter (these words): Impose punishment upon me earlier in this world, what Thou art going to impose upon me in the Hereafter. Thereupon Allah's Messenger (ﷺ) said: Hallowed be Allah, you have neither the power nor forbearance to take upon yourself (the burden of His Punishment). Why did you not say this: O Allah, grant us good in the world and good in the Hereafter, and save us from the torment of Fire. He (the Holy Prophet) made this supplication (for him) and he was all right}}
\hadithdefcmd{muslim}{6836}{حَدَّثَنَاهُ عَاصِمُ بْنُ النَّضْرِ التَّيْمِيُّ، حَدَّثَنَا خَالِدُ بْنُ الْحَارِثِ، حَدَّثَنَا حُمَيْدٌ، بِهَذَا الإِسْنَادِ إِلَى قَوْلِهِ ‏ "‏ وَقِنَا عَذَابَ النَّارِ ‏"‏ ‏.‏ وَلَمْ يَذْكُرِ الزِّيَادَةَ ‏.‏\hadithno{6836}\hadithtrans{This hadith has been narrated on the authority of Humaid with the same chain of transmitters, but with a slight variation of wording}}
\hadithdefcmd{muslim}{6837}{وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا عَفَّانُ، حَدَّثَنَا حَمَّادٌ، أَخْبَرَنَا ثَابِتٌ، عَنْ أَنَسٍ، أَنَّعليه وسلم دَخَلَ عَلَى رَجُلٍ مِنْ أَصْحَابِهِ يَعُودُهُ وَقَدْ صَارَ كَالْفَرْخِ ‏.‏ بِمَعْنَى حَدِيثِ حُمَيْدٍ غَيْرَ أَنَّهُ قَالَ ‏ "‏ لاَ طَاقَةَ لَكَ بِعَذَابِ اللَّهِ ‏"‏ ‏.‏ وَلَمْ يَذْكُرْ فَدَعَا اللَّهَ لَهُ فَشَفَاهُ ‏.‏\hadithno{6837}\hadithtrans{Anas reported that Allah's Messenger (ﷺ) visited a person from amongst his Companions who had grown as feeble as the chicken. The rest of the hadith is the same, but with this variation that he (the Holy Prophet) said:You have not power enough to undergo the torment imposed by Allah. And there is no mention of: He supplicated Allah for him and He cured him}}
\hadithdefcmd{muslim}{6838}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالاَ حَدَّثَنَا سَالِمُ بْنُ نُوحٍ الْعَطَّارُ، عَنْ سَعِيدِ، بْنِ أَبِي عَرُوبَةَ عَنْ قَتَادَةَ، عَنْ أَنَسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِهَذَا الْحَدِيثِ ‏.‏\hadithno{6838}\hadithtrans{This hadith had been transmitted on the authority of Anas through another chain of narrators}}
\hadithdefcmd{muslim}{6839}{حَدَّثَنَا مُحَمَّدُ بْنُ حَاتِمِ بْنِ مَيْمُونٍ، حَدَّثَنَا بَهْزٌ، حَدَّثَنَا وُهَيْبٌ، حَدَّثَنَا سُهَيْلٌ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ لِلَّهِ تَبَارَكَ وَتَعَالَى مَلاَئِكَةً سَيَّارَةً فُضْلاً يَتَبَّعُونَ مَجَالِسَ الذِّكْرِ فَإِذَا وَجَدُوا مَجْلِسًا فِيهِ ذِكْرٌ قَعَدُوا مَعَهُمْ وَحَفَّ بَعْضُهُمْ بَعْضًا بِأَجْنِحَتِهِمْ حَتَّى يَمْلَئُوا مَا بَيْنَهُمْ وَبَيْنَ السَّمَاءِ الدُّنْيَا فَإِذَا تَفَرَّقُوا عَرَجُوا وَصَعِدُوا إِلَى السَّمَاءِ - قَالَ - فَيَسْأَلُهُمُ اللَّهُ عَزَّ وَجَلَّ وَهُوَ أَعْلَمُ بِهِمْ مِنْ أَيْنَ جِئْتُمْ فَيَقُولُونَ جِئْنَا مِنْ عِنْدِ عِبَادٍ لَكَ فِي الأَرْضِ يُسَبِّحُونَكَ وَيُكَبِّرُونَكَ وَيُهَلِّلُونَكَ وَيَحْمَدُونَكَ وَيَسْأَلُونَكَ ‏.‏ قَالَ وَمَاذَا يَسْأَلُونِي قَالُوا يَسْأَلُونَكَ جَنَّتَكَ ‏.‏ قَالَ وَهَلْ رَأَوْا جَنَّتِي قَالُوا لاَ أَىْ رَبِّ ‏.‏ قَالَ فَكَيْفَ لَوْ رَأَوْا جَنَّتِي قَالُوا وَيَسْتَجِيرُونَكَ ‏.‏ قَالَ وَمِمَّ يَسْتَجِيرُونَنِي قَالُوا مِنْ نَارِكَ يَا رَبِّ ‏.‏ قَالَ وَهَلْ رَأَوْا نَارِي قَالُوا لاَ ‏.‏ قَالَ فَكَيْفَ لَوْ رَأَوْا نَارِي قَالُوا وَيَسْتَغْفِرُونَكَ - قَالَ - فَيَقُولُ قَدْ غَفَرْتُ لَهُمْ فَأَعْطَيْتُهُمْ مَا سَأَلُوا وَأَجَرْتُهُمْ مِمَّا اسْتَجَارُوا - قَالَ - فَيَقُولُونَ رَبِّ فِيهِمْ فُلاَنٌ عَبْدٌ خَطَّاءٌ إِنَّمَا مَرَّ فَجَلَسَ مَعَهُمْ قَالَ فَيَقُولُ وَلَهُ غَفَرْتُ هُمُ الْقَوْمُ لاَ يَشْقَى بِهِمْ جَلِيسُهُمْ ‏"‏ ‏.‏\hadithno{6839}\hadithtrans{Abu Huraira reported Allah's Apostle (ﷺ) as saying Allah has mobile (squads) of angels, who have no other work (to attend to but) to follow the assemblies of Dhikr and when they find such assemblies in which there is Dhikr (of Allah) they sit in them and some of them surround the others with their wings till the space between them and the sky of the world is fully covered, and when they disperse (after the assembly of Dhikr is adjourned) they go upward to the heaven and Allah, the Exalted and Glorious, asks them although He is best informed about them:Where have you come from? They say: We come from Thine servants upon the earth who had been glorifying Thee (reciting Subhan Allah), uttering Thine Greatness (saying Allah o-Akbar) and uttering Thine Oneness (La ilaha ill Allah) and praising Thee (uttering al-Hamdu Lillah) and begging of Thee. Be would say: What do they beg of Me? They would say: They beg of Thee the Paradise of Thine. He (God) would say: Have they seen My Paradise? They said: No, our Lord. He would say: (What it would be then) if they were to see Mine Paradise? They (the angels) said: They seek Thine protection. He (the Lord) would say: Against what do they seek protection of Mine? They (the angels) would say: Our Lord, from the Hell-Fire. He (the Lord) would say: Have they seen My Fire? They would say: No. He (the Lord) would say: What it would be if they were to see My Fire? They would say: They beg of Thee forgiveness. He would say: I grant pardon to them, and confer upon them what they ask for and grant them protection against which they seek protection. They (the angels) would again say: Our Lord, there is one amongst them such and such simple servant who happened to pass by (that assembly) and sat there along with them (who had been participating in that assembly). He (the Lord) would say: I also grant him pardon, for they are a people the seat-fellows of whom are in no way unfortunate}}
\hadithdefcmd{muslim}{6840}{حَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا إِسْمَاعِيلُ، - يَعْنِي ابْنَ عُلَيَّةَ - عَنْ عَبْدِ الْعَزِيزِ، - وَهُوَ ابْنُ صُهَيْبٍ - قَالَ سَأَلَ قَتَادَةُ أَنَسًا أَىُّ دَعْوَةٍ كَانَ يَدْعُو بِهَا النَّبِيُّ صلى الله عليه وسلم أَكْثَرَ قَالَ كَانَ أَكْثَرُ دَعْوَةٍ يَدْعُو بِهَا يَقُولُ ‏ "‏ اللَّهُمَّ آتِنَا فِي الدُّنْيَا حَسَنَةً وَفِي الآخِرَةِ حَسَنَةً وَقِنَا عَذَابَ النَّارِ ‏"‏ ‏.‏ قَالَ وَكَانَ أَنَسٌ إِذَا أَرَادَ أَنْ يَدْعُوَ بِدَعْوَةٍ دَعَا بِهَا فَإِذَا أَرَادَ أَنْ يَدْعُوَ بِدُعَاءٍ دَعَا بِهَا فِيهِ ‏.‏\hadithno{6840}\hadithtrans{Qatada asked Anas which Supplication Allah's Apostle (ﷺ) frequently made. He said:The supplication that he (the Prophet made very frequently is this:" O Allah, grant us the good in this world and the good in the Hereafter and save us from the torment of Hell-Fire." He (Qatada) said that whenever Anas had to supplicate he made this very supplication, and whenever he (intended) to make another supplication he (inserted) this very supplication in that}}
\hadithdefcmd{muslim}{6841}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا شُعْبَةُ، عَنْ ثَابِتٍ، عَنْ أَنَسٍ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ رَبَّنَا آتِنَا فِي الدُّنْيَا حَسَنَةً وَفِي الآخِرَةِ حَسَنَةً وَقِنَا عَذَابَ النَّارِ ‏"‏ ‏.‏\hadithno{6841}\hadithtrans{Anas reported that Allah's Messenger (ﷺ) used to supplicate (in these words):" Our Lord, grant us the good in this world and the good in the Hereafter and save us from the torment of Hell Fire}}
\hadithdefcmd{muslim}{6842}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ سُمَىٍّ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ قَالَ لاَ إِلَهَ إِلاَّ اللَّهُ وَحْدَهُ لاَ شَرِيكَ لَهُ لَهُ الْمُلْكُ وَلَهُ الْحَمْدُ وَهُوَ عَلَى كُلِّ شَىْءٍ قَدِيرٌ ‏.‏ فِي يَوْمٍ مِائَةَ مَرَّةٍ ‏.‏ كَانَتْ لَهُ عَدْلَ عَشْرِ رِقَابٍ وَكُتِبَتْ لَهُ مِائَةُ حَسَنَةٍ وَمُحِيَتْ عَنْهُ مِائَةُ سَيِّئَةٍ وَكَانَتْ لَهُ حِرْزًا مِنَ الشَّيْطَانِ يَوْمَهُ ذَلِكَ حَتَّى يُمْسِيَ وَلَمْ يَأْتِ أَحَدٌ أَفْضَلَ مِمَّا جَاءَ بِهِ إِلاَّ أَحَدٌ عَمِلَ أَكْثَرَ مِنْ ذَلِكَ ‏.‏ وَمَنْ قَالَ سُبْحَانَ اللَّهِ وَبِحَمْدِهِ فِي يَوْمٍ مِائَةَ مَرَّةٍ حُطَّتْ خَطَايَاهُ وَلَوْ كَانَتْ مِثْلَ زَبَدِ الْبَحْرِ ‏"‏ ‏.‏\hadithno{6842}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:He who uttered these words:" There is no god but Allah, the One, having no partner with Him. Sovereignty belongs to Him and all the praise is due to Him, and He is Potent over everything" one hundred times every day there is a reward of emancipating ten slaves for him, and there are recorded hundred virtues to his credit, and hundred vices are blotted out from his scroll, and that is a safeguard for him against the Satan on that day till evening and no one brings anything more excellent than this, except one who has done more than this (who utters these words more than one hundred times and does more good acts) and he who utters:" Hallowed be Allah, and all praise is due to Him," one hundred times a day, his sins are obliterated even if they are equal to the extent of the foam of the ocean}}
\hadithdefcmd{muslim}{6843}{حَدَّثَنِي مُحَمَّدُ بْنُ عَبْدِ الْمَلِكِ الأُمَوِيُّ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ الْمُخْتَارِ، عَنْ سُهَيْلٍ، عَنْ سُمَىٍّ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ قَالَ حِينَ يُصْبِحُ وَحِينَ يُمْسِي سُبْحَانَ اللَّهِ وَبِحَمْدِهِ مِائَةَ مَرَّةٍ ‏.‏ لَمْ يَأْتِ أَحَدٌ يَوْمَ الْقِيَامَةِ بِأَفْضَلَ مِمَّا جَاءَ بِهِ إِلاَّ أَحَدٌ قَالَ مِثْلَ مَا قَالَ أَوْ زَادَ عَلَيْهِ ‏"‏ ‏.‏\hadithno{6843}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:He who recites in the morning and in the evening (these words):" Hallowed be Allah and all praise is due to Him" one hundred times, he would not bring on the Day of Resurrection anything excellent than this except one who utters these words or utters more than these words}}
\hadithdefcmd{muslim}{6846}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، وَزُهَيْرُ بْنُ حَرْبٍ، وَأَبُو كُرَيْبٍ وَمُحَمَّدُ بْنُ طَرِيفٍ الْبَجَلِيُّ قَالُوا حَدَّثَنَا ابْنُ فُضَيْلٍ، عَنْ عُمَارَةَ بْنِ الْقَعْقَاعِ، عَنْ أَبِي زُرْعَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ كَلِمَتَانِ خَفِيفَتَانِ عَلَى اللِّسَانِ ثَقِيلَتَانِ فِي الْمِيزَانِ حَبِيبَتَانِ إِلَى الرَّحْمَنِ سُبْحَانَ اللَّهِ وَبِحَمْدِهِ سُبْحَانَ اللَّهِ الْعَظِيمِ ‏"‏ ‏.‏\hadithno{6846}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:Two are the expressions which are light on the tongue, but heavy in scale, dear to the Compassionate One:" Hallowed be Allah and praise is due to Him" ;" Hallowed be Allah, the Great}}
\hadithdefcmd{muslim}{6847}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو كُرَيْبٍ قَالاَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لأَنْ أَقُولَ سُبْحَانَ اللَّهِ وَالْحَمْدُ لِلَّهِ وَلاَ إِلَهَ إِلاَّ اللَّهُ وَاللَّهُ أَكْبَرُ أَحَبُّ إِلَىَّ مِمَّا طَلَعَتْ عَلَيْهِ الشَّمْسُ ‏"‏ ‏.‏\hadithno{6847}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:The uttering of (these words):" Hallowed be Allah; all praise is due to Allah, there is no god but Allah and Allah is the Greatest," is dearer to me than anything over which the sun rises}}
\hadithdefcmd{muslim}{6848}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، وَابْنُ، نُمَيْرٍ عَنْ مُوسَى الْجُهَنِيِّ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، - وَاللَّفْظُ لَهُ - حَدَّثَنَا أَبِي، حَدَّثَنَا مُوسَى الْجُهَنِيُّ، عَنْ مُصْعَبِ بْنِ سَعْدٍ، عَنْ أَبِيهِ، قَالَ جَاءَ أَعْرَابِيٌّ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ عَلِّمْنِي كَلاَمًا أَقُولُهُ قَالَ ‏"‏ قُلْ لاَ إِلَهَ إِلاَّ اللَّهُ وَحْدَهُ لاَ شَرِيكَ لَهُ اللَّهُ أَكْبَرُ كَبِيرًا وَالْحَمْدُ لِلَّهِ كَثِيرًا سُبْحَانَ اللَّهِ رَبِّ الْعَالَمِينَ لاَ حَوْلَ وَلاَ قُوَّةَ إِلاَّ بِاللَّهِ الْعَزِيزِ الْحَكِيمِ ‏"‏ ‏.‏ قَالَ فَهَؤُلاَءِ لِرَبِّي فَمَا لِي قَالَ ‏"‏ قُلِ اللَّهُمَّ اغْفِرْ لِي وَارْحَمْنِي وَاهْدِنِي وَارْزُقْنِي ‏"‏ ‏.‏ قَالَ مُوسَى أَمَّا عَافِنِي فَأَنَا أَتَوَهَّمُ وَمَا أَدْرِي ‏.‏ وَلَمْ يَذْكُرِ ابْنُ أَبِي شَيْبَةَ فِي حَدِيثِهِ قَوْلَ مُوسَى ‏.‏\hadithno{6848}\hadithtrans{Mu'sab b. Sa'd reported on the authority of his father that a desert Arab came to Allah's Messenger (ﷺ) and said to him:Teach me the words which I should (often) utter. He said: Utter," There is no god but Allah, the One, having no partner with Him. Allah is the Greatest of the great and all praise is due to Him. Hallowed be Allah, the Lord of the worlds, there is no Might and Power but that of Allah, the All-Powerful and the Wise." He (that desert Arab) said: These all (glorify) my Lord. But what about me? Thereupon he (the Holy Prophet) said: You should say:" O Allah, grant me pardon, have mercy upon me, direct me to righteousness and provide me sustenance." Musa (one of the narrators) said: I think he also said:" Grant me safety." But I cannot say for certain whether he said this or not. Ibn Abi Shaiba has not made a mention of the words of Musa in his narration}}
\hadithdefcmd{muslim}{6849}{حَدَّثَنَا أَبُو كَامِلٍ الْجَحْدَرِيُّ، حَدَّثَنَا عَبْدُ الْوَاحِدِ، - يَعْنِي ابْنَ زِيَادٍ - حَدَّثَنَا أَبُو مَالِكٍ الأَشْجَعِيُّ عَنْ أَبِيهِ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُعَلِّمُ مَنْ أَسْلَمَ يَقُولُ ‏ "‏ اللَّهُمَّ اغْفِرْ لِي وَارْحَمْنِي وَاهْدِنِي وَارْزُقْنِي ‏"‏ ‏.‏\hadithno{6849}\hadithtrans{Abu Malik Ashaja'i reported on the authority of his father that whenever a person embraced Islam, Allah's Messenger (ﷺ) instructed him to recilte:" O Allah, grant me pardon, have mercy upon me, direct me to the path of righteousness and provide me sustenance}}
\hadithdefcmd{muslim}{6850}{حَدَّثَنَا سَعِيدُ بْنُ أَزْهَرَ الْوَاسِطِيُّ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، حَدَّثَنَا أَبُو مَالِكٍ الأَشْجَعِيُّ، عَنْ أَبِيهِ، قَالَ كَانَ الرَّجُلُ إِذَا أَسْلَمَ عَلَّمَهُ النَّبِيُّ صلى الله عليه وسلم الصَّلاَةَ ثُمَّ أَمَرَهُ أَنْ يَدْعُوَ بِهَؤُلاَءِ الْكَلِمَاتِ ‏ "‏ اللَّهُمَّ اغْفِرْ لِي وَارْحَمْنِي وَاهْدِنِي وَعَافِنِي وَارْزُقْنِي ‏"‏ ‏.‏\hadithno{6850}\hadithtrans{Abu Malik reported on the authority of his father that when a person embraced Islam, Allah's Messenger (ﷺ) used to teach him how to observe prayer and then commanded him to supplicate in these words:" O Allah, grant me pardon, have mercy upon me, direct me to the path of righteousness, grant me protection and provide me sustenance}}
\hadithdefcmd{muslim}{6851}{حَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، أَخْبَرَنَا أَبُو مَالِكٍ، عَنْ أَبِيهِ، أَنَّهُ سَمِعَ النَّبِيَّ صلى الله عليه وسلم وَأَتَاهُ رَجُلٌ فَقَالَ يَا رَسُولَ اللَّهِ كَيْفَ أَقُولُ حِينَ أَسْأَلُ رَبِّي قَالَ ‏"‏ قُلِ اللَّهُمَّ اغْفِرْ لِي وَارْحَمْنِي وَعَافِنِي وَارْزُقْنِي ‏"‏ ‏.‏ وَيَجْمَعُ أَصَابِعَهُ إِلاَّ الإِبْهَامَ ‏"‏ فَإِنَّ هَؤُلاَءِ تَجْمَعُ لَكَ دُنْيَاكَ وَآخِرَتَكَ ‏"‏ ‏.‏\hadithno{6851}\hadithtrans{Abu Malik reported on the authority Of his father that he heard Allah's Messenger (ﷺ) as saying to the person who bad come to him and asked him as to how he should beg his Lord, that he should utter these words:" O Allah, grant me pardon, have mercy upon me, protect me, provide me sustenance," and he collected his fingers together except his thumb and said: It is in these words (that there is supplication) which sums up for you (the good) of this world and that of the Hereafter}}
\hadithdefcmd{muslim}{6852}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مَرْوَانُ، وَعَلِيُّ بْنُ مُسْهِرٍ، عَنْ مُوسَى الْجُهَنِيِّ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، - وَاللَّفْظُ لَهُ - حَدَّثَنَا أَبِي، حَدَّثَنَا مُوسَى الْجُهَنِيُّ، عَنْ مُصْعَبِ بْنِ سَعْدٍ، حَدَّثَنِي أَبِي قَالَ، كُنَّا عِنْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ أَيَعْجِزُ أَحَدُكُمْ أَنْ يَكْسِبَ كُلَّ يَوْمٍ أَلْفَ حَسَنَةٍ ‏"‏ ‏.‏ فَسَأَلَهُ سَائِلٌ مِنْ جُلَسَائِهِ كَيْفَ يَكْسِبُ أَحَدُنَا أَلْفَ حَسَنَةٍ قَالَ ‏"‏ يُسَبِّحُ مِائَةَ تَسْبِيحَةٍ فَيُكْتَبُ لَهُ أَلْفُ حَسَنَةٍ أَوْ يُحَطُّ عَنْهُ أَلْفُ خَطِيئَةٍ ‏"‏ ‏.‏\hadithno{6852}\hadithtrans{Mus'ab b. Sa'd reported that his father told him that he had been in the company of Allah's Messenger (ﷺ) that he said:Is one amongst you powerless to get one thousand virtues every day. Amongst those who had been sitting there, one asked: How one amongst us can get one thousand virtues every day? He said: Recite:" Hallowed be Allah" one hundred times for (by reciting them) one thousand virtues are recorded (to your credit) and one tbousand vices are blotted out}}
\hadithdefcmd{muslim}{6853}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى التَّمِيمِيُّ، وَأَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ وَمُحَمَّدُ بْنُ الْعَلاَءِ الْهَمْدَانِيُّ - وَاللَّفْظُ لِيَحْيَى - قَالَ يَحْيَى أَخْبَرَنَا وَقَالَ الآخَرَانِ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ نَفَّسَ عَنْ مُؤْمِنٍ كُرْبَةً مِنْ كُرَبِ الدُّنْيَا نَفَّسَ اللَّهُ عَنْهُ كُرْبَةً مِنْ كُرَبِ يَوْمِ الْقِيَامَةِ وَمَنْ يَسَّرَ عَلَى مُعْسِرٍ يَسَّرَ اللَّهُ عَلَيْهِ فِي الدُّنْيَا وَالآخِرَةِ وَمَنْ سَتَرَ مُسْلِمًا سَتَرَهُ اللَّهُ فِي الدُّنْيَا وَالآخِرَةِ وَاللَّهُ فِي عَوْنِ الْعَبْدِ مَا كَانَ الْعَبْدُ فِي عَوْنِ أَخِيهِ وَمَنْ سَلَكَ طَرِيقًا يَلْتَمِسُ فِيهِ عِلْمًا سَهَّلَ اللَّهُ لَهُ بِهِ طَرِيقًا إِلَى الْجَنَّةِ وَمَا اجْتَمَعَ قَوْمٌ فِي بَيْتٍ مِنْ بُيُوتِ اللَّهِ يَتْلُونَ كِتَابَ اللَّهِ وَيَتَدَارَسُونَهُ بَيْنَهُمْ إِلاَّ نَزَلَتْ عَلَيْهِمُ السَّكِينَةُ وَغَشِيَتْهُمُ الرَّحْمَةُ وَحَفَّتْهُمُ الْمَلاَئِكَةُ وَذَكَرَهُمُ اللَّهُ فِيمَنْ عِنْدَهُ وَمَنْ بَطَّأَ بِهِ عَمَلُهُ لَمْ يُسْرِعْ بِهِ نَسَبُهُ ‏"‏ ‏.‏\hadithno{6853}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:He who alleviates the suffering of a brother out of the sufferings of the world, Allah would alleviate his suffering from the sufferings of the Day of Resurrection, and he who finds relief for one who is hard-pressed, Allah would make things easy for him in the Hereafter, and he who conceals (the faults) of a Muslim, Allah would conceal his faults in the world and in the Hereafter. Allah is at the back of a servant so long as the servant is at the back of his brother, and he who treads the path in search of knowledge, Allah would make that path easy, leading to Paradise for him and those persons who assemble in the house among the houses of Allah (mosques) and recite the Book of Allah and they learn and teach the Qur'an (among themselves) there would descend upon them tranquility and mercy would cover them and the angels would surround them and Allah mentions them in the presence of those near Him, and he who is slow-paced in doing good deeds, his (high) lineage does not make him go ahead}}
\hadithdefcmd{muslim}{6854}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا أَبِي ح، وَحَدَّثَنَاهُ نَصْرُ بْنُ عَلِيٍّ الْجَهْضَمِيُّ، حَدَّثَنَا أَبُو أُسَامَةَ، قَالاَ حَدَّثَنَا الأَعْمَشُ، عَنْ أَبِي صَالِحٍ، وَفِي حَدِيثِ أَبِي أُسَامَةَ حَدَّثَنَا أَبُو صَالِحٍ عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِمِثْلِ حَدِيثِ أَبِي مُعَاوِيَةَ غَيْرَ أَنَّ حَدِيثَ أَبِي أُسَامَةَ لَيْسَ فِيهِ ذِكْرُ التَّيْسِيرِ عَلَى الْمُعْسِرِ ‏.‏\hadithno{6854}\hadithtrans{This hadith has been narrated on the authority of Abu Huraira through another chain of transmitters but with a slight variation of wording}}
\hadithdefcmd{muslim}{6857}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مَرْحُومُ بْنُ عَبْدِ الْعَزِيزِ، عَنْ أَبِي نَعَامَةَ السَّعْدِيِّ، عَنْ أَبِي عُثْمَانَ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ خَرَجَ مُعَاوِيَةُ عَلَى حَلْقَةٍ فِي الْمَسْجِدِ فَقَالَ مَا أَجْلَسَكُمْ قَالُوا جَلَسْنَا نَذْكُرُ اللَّهَ ‏.‏ قَالَ آللَّهِ مَا أَجْلَسَكُمْ إِلاَّ ذَاكَ قَالُوا وَاللَّهِ مَا أَجْلَسَنَا إِلاَّ ذَاكَ ‏.‏ قَالَ أَمَا إِنِّي لَمْ أَسْتَحْلِفْكُمْ تُهْمَةً لَكُمْ وَمَا كَانَ أَحَدٌ بِمَنْزِلَتِي مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَقَلَّ عَنْهُ حَدِيثًا مِنِّي وَإِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم خَرَجَ عَلَى حَلْقَةٍ مِنْ أَصْحَابِهِ فَقَالَ ‏"‏ مَا أَجْلَسَكُمْ ‏"‏ ‏.‏ قَالُوا جَلَسْنَا نَذْكُرُ اللَّهَ وَنَحْمَدُهُ عَلَى مَا هَدَانَا لِلإِسْلاَمِ وَمَنَّ بِهِ عَلَيْنَا ‏.‏ قَالَ ‏"‏ آللَّهِ مَا أَجْلَسَكُمْ إِلاَّ ذَاكَ ‏"‏ ‏.‏ قَالُوا وَاللَّهِ مَا أَجْلَسَنَا إِلاَّ ذَاكَ ‏.‏ قَالَ ‏"‏ أَمَا إِنِّي لَمْ أَسْتَحْلِفْكُمْ تُهْمَةً لَكُمْ وَلَكِنَّهُ أَتَانِي جِبْرِيلُ فَأَخْبَرَنِي أَنَّ اللَّهَ عَزَّ وَجَلَّ يُبَاهِي بِكُمُ الْمَلاَئِكَةَ ‏"‏ ‏.‏\hadithno{6857}\hadithtrans{Abu Sa'id Khudri reported that Mu'awiya went to a circle in the mosque and said:What makes you sit here? They said: We are sitting here in order to remember Allah. He said: I adjure you by Allah (to tell me whether you are sitting here for this very purpose)? They said: By Allah, we are sitting here for this very purpose. Thereupon, he said: I have not demanded you to take an oath, because of any allegation against you and none of my rank in the eye of Allah's Messenger (ﷺ) is the narrator of so few ahadith as I am. The fact is that Allah's Messenger (ﷺ) went out to the circle of his Companions and said: What makes you sit? They said: We are sitting here in order to remember Allah and to praise Him for He guided us to the path of Islam and He conferred favours upon us. Thereupon he adjured by Allah and asked if that only was the purpose of their sitting there. They said: By Allah, we are not sitting here but for this very purpose, whereupon he (the Messenger) said: I am not asking you to take an oath because of any allegation against you but for the fact that Gabriel came to me and he informed me that Allah, the Exalted and Glorious, was talking to the angels about your magnificence}}
\hadithdefcmd{muslim}{6858}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَقُتَيْبَةُ بْنُ سَعِيدٍ، وَأَبُو الرَّبِيعِ الْعَتَكِيُّ، جَمِيعًا عَنْ حَمَّادٍ، قَالَ يَحْيَى أَخْبَرَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ ثَابِتٍ، عَنْ أَبِي بُرْدَةَ، عَنِ الأَغَرِّ الْمُزَنِيِّ، - وَكَانَتْ لَهُ صُحْبَةٌ - أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّهُ لَيُغَانُ عَلَى قَلْبِي وَإِنِّي لأَسْتَغْفِرُ اللَّهَ فِي الْيَوْمِ مِائَةَ مَرَّةٍ ‏"‏ ‏.‏\hadithno{6858}\hadithtrans{Al-Agharr al-Muzani, who was one amongst the Companions (of the Holy Prophet) reported that Allah's Messenger (ﷺ) said:There is (at times) some sort of shade upon my heart, and I seek forgiveness from Allah a hundred times a day}}
\hadithdefcmd{muslim}{6859}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا غُنْدَرٌ، عَنْ شُعْبَةَ، عَنْ عَمْرِو بْنِ مُرَّةَ، عَنْ أَبِي، بُرْدَةَ قَالَ سَمِعْتُ الأَغَرَّ، وَكَانَ، مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم يُحَدِّثُ ابْنَ عُمَرَ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يَا أَيُّهَا النَّاسُ تُوبُوا إِلَى اللَّهِ فَإِنِّي أَتُوبُ فِي الْيَوْمِ إِلَيْهِ مِائَةَ مَرَّةٍ ‏"‏ ‏.‏\hadithno{6859}\hadithtrans{Al-Agharr al-Muzani who was from amongst the Companions of Allah's Apostle (ﷺ) reported that Ibn 'Umar stated to him that Allah's Messenger (may peace 'be upon him) said:O people, seek repentance from Allah. Verily, I seek repentance from Him a hundred times a day}}
\hadithdefcmd{muslim}{6860}{حَدَّثَنَاهُ عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، حَدَّثَنَا أَبِي ح، وَحَدَّثَنَا ابْنُ الْمُثَنَّى، حَدَّثَنَا أَبُو دَاوُدَ، وَعَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ كُلُّهُمْ عَنْ شُعْبَةَ، فِي هَذَا الإِسْنَادِ ‏.‏\hadithno{6860}\hadithtrans{This hadith has been narrated on the authority of Shu'ba with the same chain of transmitters}}
\hadithdefcmd{muslim}{6861}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو خَالِدٍ يَعْنِي سُلَيْمَانَ بْنَ حَيَّانَ، ح وَحَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، ح وَحَدَّثَنِي أَبُو سَعِيدٍ الأَشَجُّ، حَدَّثَنَا حَفْصٌ، - يَعْنِي ابْنَ غِيَاثٍ - كُلُّهُمْ عَنْ هِشَامٍ، ح وَحَدَّثَنِي أَبُو خَيْثَمَةَ، زُهَيْرُ بْنُ حَرْبٍ - وَاللَّفْظُ لَهُ - حَدَّثَنَا إِسْمَاعِيلُ، بْنُ إِبْرَاهِيمَ عَنْ هِشَامِ بْنِ حَسَّانَ، عَنْ مُحَمَّدِ بْنِ سِيرِينَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ تَابَ قَبْلَ أَنْ تَطْلُعَ الشَّمْسُ مِنْ مَغْرِبِهَا تَابَ اللَّهُ عَلَيْهِ ‏"‏ ‏.‏\hadithno{6861}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as say- ing:He who seeks repentance (from the Lord) before the rising of the sun from the west (before the Day of Resurrection), Allah turns to him with Mercy}}
\hadithdefcmd{muslim}{6862}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُحَمَّدُ بْنُ فُضَيْلٍ، وَأَبُو مُعَاوِيَةَ عَنْ عَاصِمٍ، عَنْ أَبِي عُثْمَانَ، عَنْ أَبِي مُوسَى، قَالَ كُنَّا مَعَ النَّبِيِّ صلى الله عليه وسلم فِي سَفَرٍ فَجَعَلَ النَّاسُ يَجْهَرُونَ بِالتَّكْبِيرِ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ أَيُّهَا النَّاسُ ارْبَعُوا عَلَى أَنْفُسِكُمْ إِنَّكُمْ لَيْسَ تَدْعُونَ أَصَمَّ وَلاَ غَائِبًا إِنَّكُمْ تَدْعُونَ سَمِيعًا قَرِيبًا وَهُوَ مَعَكُمْ ‏"‏ ‏.‏ قَالَ وَأَنَا خَلْفَهُ وَأَنَا أَقُولُ لاَ حَوْلَ وَلاَ قُوَّةَ إِلاَّ بِاللَّهِ فَقَالَ ‏"‏ يَا عَبْدَ اللَّهِ بْنَ قَيْسٍ أَلاَ أَدُلُّكَ عَلَى كَنْزٍ مِنْ كُنُوزِ الْجَنَّةِ ‏"‏ ‏.‏ فَقُلْتُ بَلَى يَا رَسُولَ اللَّهِ ‏.‏ قَالَ ‏"‏ قُلْ لاَ حَوْلَ وَلاَ قُوَّةَ إِلاَّ بِاللَّهِ ‏"‏ ‏.‏\hadithno{6862}\hadithtrans{Abu Musa reported:We were along with Allah's Apostle (ﷺ) on a journey when the people began to pronounce "Allahu Akbar" in a loud voice. Thereupon Allah's Messenger (ﷺ) said: O people, show mercy to yourselves for you are not calling One who is deaf or absent. Verily, you are calling One who is All-Hearing (and) Near to you and is with you. Abu Musa said that he had been behind him (the Prophet) and reciting: "There is neither might nor power but that of Allah." He (the Prophet), while addressing 'Abdullah b. Qais, said: Should I not direct you to a treasure from amongst the treasures of Paradise? I ('Abdullah b. Qais) said: Allah's Messenger, do it, of course. Thereupon he (the Prophet) said: Then recite: "There is no might and no power but that of Allah}}
\hadithdefcmd{muslim}{6863}{حَدَّثَنَا ابْنُ نُمَيْرٍ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَأَبُو سَعِيدٍ الأَشَجُّ جَمِيعًا عَنْ حَفْصِ بْنِ، غِيَاثٍ عَنْ عَاصِمٍ، بِهَذَا الإِسْنَادِ نَحْوَهُ ‏.‏\hadithno{6863}\hadithtrans{This hadith has been narrated on the authority of 'Asim with the same chain of transmitters}}
\hadithdefcmd{muslim}{6864}{حَدَّثَنَا أَبُو كَامِلٍ، فُضَيْلُ بْنُ حُسَيْنٍ حَدَّثَنَا يَزِيدُ، - يَعْنِي ابْنَ زُرَيْعٍ - حَدَّثَنَا التَّيْمِيُّ، عَنْ أَبِي عُثْمَانَ، عَنْ أَبِي مُوسَى، أَنَّهُمْ كَانُوا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم وَهُمْ يَصْعَدُونَ فِي ثَنِيَّةٍ - قَالَ - فَجَعَلَ رَجُلٌ كُلَّمَا عَلاَ ثَنِيَّةً نَادَى لاَ إِلَهَ إِلاَ اللَّهُ وَاللَّهُ أَكْبَرُ - قَالَ - فَقَالَ نَبِيُّ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّكُمْ لاَ تُنَادُونَ أَصَمَّ وَلاَ غَائِبًا ‏"‏ ‏.‏ قَالَ فَقَالَ ‏"‏ يَا أَبَا مُوسَى - أَوْ يَا عَبْدَ اللَّهِ بْنَ قَيْسٍ - أَلاَ أَدُلُّكَ عَلَى كَلِمَةٍ مِنْ كَنْزِ الْجَنَّةِ ‏"‏ ‏.‏ قُلْتُ مَا هِيَ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ لاَ حَوْلَ وَلاَ قُوَّةَ إِلاَّ بِاللَّهِ ‏"‏ ‏.‏\hadithno{6864}\hadithtrans{Abu Musa reported that he (and his other companions) were climbing upon the hillock along with Allah's Messenger (ﷺ) and when any person climbed up, he pronounced (loudly):" There is no god but Allah, Allah is the Greatest." Thereupon Allah's Apostle (ﷺ) said: Verily, you are not supplicating One Who is deaf or absent. He said: Abu Musa or Abdullah b Qais, should I not direct you to the words (which form) the treasure of Paradise? I said: Allah's Messenger, what are these? He said:" There is no might and no power but that of Allah}}
\hadithdefcmd{muslim}{6865}{وَحَدَّثَنَاهُ مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، حَدَّثَنَا الْمُعْتَمِرُ، عَنْ أَبِيهِ، حَدَّثَنَا أَبُو عُثْمَانَ، عَنْ أَبِي مُوسَى، قَالَ بَيْنَمَا رَسُولُ اللَّهِ صلى الله عليه وسلم فَذَكَرَ نَحْوَهُ ‏.‏\hadithno{6865}\hadithtrans{This hadith has been transmitted on the authority of Abu Musa with a slight variation of wording}}
\hadithdefcmd{muslim}{6866}{حَدَّثَنَا خَلَفُ بْنُ هِشَامٍ، وَأَبُو الرَّبِيعِ، قَالاَ حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ أَيُّوبَ، عَنْ أَبِي، عُثْمَانَ عَنْ أَبِي مُوسَى، قَالَ كُنَّا مَعَ النَّبِيِّ صلى الله عليه وسلم فِي سَفَرٍ ‏.‏ فَذَكَرَ نَحْوَ حَدِيثِ عَاصِمٍ ‏.‏\hadithno{6866}\hadithtrans{Abu Musa reported:We were along with Allah's Apostle (ﷺ) on a journey; the rest of the hadith is the same as transmitted by A'sim}}
\hadithdefcmd{muslim}{6867}{وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا الثَّقَفِيُّ، حَدَّثَنَا خَالِدٌ الْحَذَّاءُ، عَنْ أَبِي عُثْمَانَ، عَنْ أَبِي مُوسَى، قَالَ كُنَّا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي غَزَاةٍ ‏.‏ فَذَكَرَ الْحَدِيثَ وَقَالَ فِيهِ ‏ "‏ وَالَّذِي تَدْعُونَهُ أَقْرَبُ إِلَى أَحَدِكُمْ مِنْ عُنُقِ رَاحِلَةِ أَحَدِكُمْ ‏"‏ ‏.‏ وَلَيْسَ فِي حَدِيثِهِ ذِكْرُ لاَ حَوْلَ وَلاَ قُوَّةَ إِلاَّ بِاللَّهِ ‏.‏\hadithno{6867}\hadithtrans{Abu Musa, reported. We were along with Allah's Messenger (ﷺ) in an expedition. The rest of the hadith is the same (and there is an addi- tion of these words in that):" He (the Holy Prophet) said: He Whom you are sup- plicating is nearer to every one of you than the neck of his camel." And there is no mention of these words:" There is no might and no power but that of Allah}}
\hadithdefcmd{muslim}{6868}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا النَّضْرُ بْنُ شُمَيْلٍ، حَدَّثَنَا عُثْمَانُ، - وَهُوَ ابْنُ غِيَاثٍ - حَدَّثَنَا أَبُو عُثْمَانَ، عَنْ أَبِي مُوسَى الأَشْعَرِيِّ، قَالَ قَالَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَلاَ أَدُلُّكَ عَلَى كَلِمَةٍ مِنْ كُنُوزِ الْجَنَّةِ - أَوْ قَالَ - عَلَى كَنْزٍ مِنْ كُنُوزِ الْجَنَّةِ ‏"‏ ‏.‏ فَقُلْتُ بَلَى ‏.‏ فَقَالَ ‏"‏ لاَ حَوْلَ وَلاَ قُوَّةَ إِلاَّ بِاللَّهِ ‏"‏ ‏.‏\hadithno{6868}\hadithtrans{Abu Musa Ash'ari reported that Allah's Messenger (ﷺ) said to him:Should I not direct you to the words from the treasures of Paradise, or he said: Like a treasure from the treasures of Paradise? I said: Of course, do that. Thereupon he said:" There is no might and no power but that of Allah}}
\hadithdefcmd{muslim}{6869}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا لَيْثٌ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ، أَخْبَرَنَا اللَّيْثُ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ أَبِي الْخَيْرِ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، عَنْ أَبِي بَكْرٍ، أَنَّهُ قَالَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم عَلِّمْنِي دُعَاءً أَدْعُو بِهِ فِي صَلاَتِي قَالَ ‏ "‏ قُلِ اللَّهُمَّ إِنِّي ظَلَمْتُ نَفْسِي ظُلْمًا كَبِيرًا - وَقَالَ قُتَيْبَةُ كَثِيرًا - وَلاَ يَغْفِرُ الذُّنُوبَ إِلاَّ أَنْتَ فَاغْفِرْ لِي مَغْفِرَةً مِنْ عِنْدِكَ وَارْحَمْنِي إِنَّكَ أَنْتَ الْغَفُورُ الرَّحِيمُ ‏"‏ ‏.‏\hadithno{6869}\hadithtrans{Abu Bakr reported that he said to Allah's Messenger (ﷺ):Teach me a supplication which I should recite in my prayer. Thereupon he (the Holy Prophet) said: Recite:" O Allah, I have done great wrong to myself." According to Qutaiba (the words were: ) much (wrong) -there is none to forgive the sins but Thou only, say:" Grant me pardon from Thyself, have mercy upon me for Thou art much Forgiving and Compassionate}}
\hadithdefcmd{muslim}{6870}{وَحَدَّثَنِيهِ أَبُو الطَّاهِرِ، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَخْبَرَنِي رَجُلٌ، سَمَّاهُ وَعَمْرُو بْنُ الْحَارِثِ عَنْ يَزِيدَ بْنَ أَبِي حَبِيبٍ، عَنْ أَبِي الْخَيْرِ، أَنَّهُ سَمِعَ عَبْدَ اللَّهِ بْنِ عَمْرِو بْنِ الْعَاصِ، يَقُولُ إِنَّ أَبَا بَكْرٍ الصِّدِّيقَ قَالَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم عَلِّمْنِي يَا رَسُولَ اللَّهِ دُعَاءً أَدْعُو بِهِ فِي صَلاَتِي وَفِي بَيْتِي ‏.‏ ثُمَّ ذَكَرَ بِمِثْلِ حَدِيثِ اللَّيْثِ غَيْرَ أَنَّهُ قَالَ ‏ "‏ ظُلْمًا كَثِيرًا ‏"‏ ‏.‏\hadithno{6870}\hadithtrans{This hadith has been transmitted on the authority of 'Amr b. al-'As that Abu Bakr Siddiq said to Allah's Messenger (ﷺ) Allah's Messenger, teach me a supplication which I should make in my prayer and in my house. The rest of the hadith is the same except with this variation that he said:Much wrong (Zulman Kathira)}}
\hadithdefcmd{muslim}{6871}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو كُرَيْبٍ - وَاللَّفْظُ لأَبِي بَكْرٍ - قَالاَ حَدَّثَنَا ابْنُ، نُمَيْرٍ حَدَّثَنَا هِشَامٌ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَدْعُو بِهَؤُلاَءِ الدَّعَوَاتِ ‏ "‏ اللَّهُمَّ فَإِنِّي أَعُوذُ بِكَ مِنْ فِتْنَةِ النَّارِ وَعَذَابِ النَّارِ وَفِتْنَةِ الْقَبْرِ وَعَذَابِ الْقَبْرِ وَمِنْ شَرِّ فِتْنَةِ الْغِنَى وَمِنْ شَرِّ فِتْنَةِ الْفَقْرِ وَأَعُوذُ بِكَ مِنْ شَرِّ فِتْنَةِ الْمَسِيحِ الدَّجَّالِ اللَّهُمَّ اغْسِلْ خَطَايَاىَ بِمَاءِ الثَّلْجِ وَالْبَرَدِ وَنَقِّ قَلْبِي مِنَ الْخَطَايَا كَمَا نَقَّيْتَ الثَّوْبَ الأَبْيَضَ مِنَ الدَّنَسِ وَبَاعِدْ بَيْنِي وَبَيْنَ خَطَايَاىَ كَمَا بَاعَدْتَ بَيْنَ الْمَشْرِقِ وَالْمَغْرِبِ اللَّهُمَّ فَإِنِّي أَعُوذُ بِكَ مِنَ الْكَسَلِ وَالْهَرَمِ وَالْمَأْثَمِ وَالْمَغْرَمِ ‏"‏ ‏.‏\hadithno{6871}\hadithtrans{A'isha reported that Allah's Messenger (ﷺ) used to make these supplications:" O Allah, I seek refuge in Thee from the trial of Hell-Fire; and from the torment of Hell-Fire; and from the trial of the grave and torment of the grave; and from the evil of the trial of the affluence and from the evil of the trial of poverty and I seek refuge in Thee from the evil of the turmoil of the Dajjal. O Allah, wash away my sins with snow and hail water, purify my heart from the sins as is purified the white garment from the dirt, and keep away at a distance the sins from me as yawns the distance between the East and the West; O Allah, I seek refuge in Thee from sloth, from senility, from sin, and from debt}}
\hadithdefcmd{muslim}{6872}{وَحَدَّثَنَاهُ أَبُو كُرَيْبٍ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، وَوَكِيعٌ، عَنْ هِشَامٍ، بِهَذَا الإِسْنَادِ ‏.‏\hadithno{6872}\hadithtrans{This hadith has been narrated on the authority of Hisham with the same chain of transmitters}}
\hadithdefcmd{muslim}{6873}{حَدَّثَنَا يَحْيَى بْنُ أَيُّوبَ، حَدَّثَنَا ابْنُ عُلَيَّةَ، قَالَ وَأَخْبَرَنَا سُلَيْمَانُ التَّيْمِيُّ، حَدَّثَنَا أَنَسُ، بْنُ مَالِكٍ قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنَ الْعَجْزِ وَالْكَسَلِ وَالْجُبْنِ وَالْهَرَمِ وَالْبُخْلِ وَأَعُوذُ بِكَ مِنْ عَذَابِ الْقَبْرِ وَمِنْ فِتْنَةِ الْمَحْيَا وَالْمَمَاتِ ‏"‏ ‏.‏\hadithno{6873}\hadithtrans{Anas b. Malik reported that Allah's Messenger (ﷺ) used to say:" O Allah, I seek refuge in Thee from incapacity, from indolence, from cowardice, from senility, from miserliness, and I seek refuge in Thee from the torment of the grave and from trial of the life and death}}
\hadithdefcmd{muslim}{6874}{وَحَدَّثَنَا أَبُو كَامِلٍ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، حَدَّثَنَا مُعْتَمِرٌ، كِلاَهُمَا عَنِ التَّيْمِيِّ، عَنْ أَنَسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ بِمِثْلِهِ غَيْرَ أَنَّ يَزِيدَ لَيْسَ فِي حَدِيثِهِ قَوْلُهُ ‏ "‏ وَمِنْ فِتْنَةِ الْمَحْيَا وَالْمَمَاتِ ‏"‏ ‏.‏\hadithno{6874}\hadithtrans{Anas reported from Allah's Messenger (ﷺ) (this suppli- cation) but with this variation that these words are not found in that supplication:" From the trial of life and death}}
\hadithdefcmd{muslim}{6875}{حَدَّثَنَا أَبُو كُرَيْبٍ، مُحَمَّدُ بْنُ الْعَلاَءِ أَخْبَرَنَا ابْنُ مُبَارَكٍ، عَنْ سُلَيْمَانَ التَّيْمِيِّ، عَنْ أَنَسِ بْنِ مَالِكٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ تَعَوَّذَ مِنْ أَشْيَاءَ ذَكَرَهَا وَالْبُخْلِ ‏.‏\hadithno{6875}\hadithtrans{Anas b. Malik reported that Allah's Apostle (ﷺ) used to seek refuge in Allah from such things as mentioned in the above-mentioned hadith and from 'miserliness" too}}
\hadithdefcmd{muslim}{6876}{حَدَّثَنَا أَبُو بَكْرِ بْنُ نَافِعٍ الْعَبْدِيُّ، حَدَّثَنَا بَهْزُ بْنُ أَسَدٍ الْعَمِّيُّ، حَدَّثَنَا هَارُونُ الأَعْوَرُ، حَدَّثَنَا شُعَيْبُ بْنُ الْحَبْحَابِ، عَنْ أَنَسٍ، قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم يَدْعُو بِهَؤُلاَءِ الدَّعَوَاتِ ‏ "‏ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنَ الْبُخْلِ وَالْكَسَلِ وَأَرْذَلِ الْعُمُرِ وَعَذَابِ الْقَبْرِ وَفِتْنَةِ الْمَحْيَا وَالْمَمَاتِ ‏"‏ ‏.‏\hadithno{6876}\hadithtrans{Anas reported that Allah's Messenger (may peace he upon him) wed to make this supplication:" O Allah, I seek refuge in Thee from miserliness, from sloth and from decrepitude}}
\hadithdefcmd{muslim}{6877}{حَدَّثَنِي عَمْرٌو النَّاقِدُ، وَزُهَيْرُ بْنُ حَرْبٍ، قَالاَ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، حَدَّثَنِي سُمَىٌّ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَتَعَوَّذُ مِنْ سُوءِ الْقَضَاءِ وَمِنْ دَرَكِ الشَّقَاءِ وَمِنْ شَمَاتَةِ الأَعْدَاءِ وَمِنْ جَهْدِ الْبَلاَءِ ‏.‏ قَالَ عَمْرٌو فِي حَدِيثِهِ قَالَ سُفْيَانُ أَشُكُّ أَنِّي زِدْتُ وَاحِدَةً مِنْهَا ‏.‏\hadithno{6877}\hadithtrans{It was narrated from Abu Huraira that:Allah's Apostle (ﷺ) used to seek refuge (in Allah) from the evil of what has been decreed, from misery, from the mockery of (triumphant) enemies, and from severe calamity. `Amr (one of the narrators) said in his narration: "Sufyan said: 'I fear I may have added one of them (the phrases)}}
\hadithdefcmd{muslim}{6878}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا لَيْثٌ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ، وَاللَّفْظُ، لَهُ أَخْبَرَنَا اللَّيْثُ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنِ الْحَارِثِ بْنِ يَعْقُوبَ، أَنَّ يَعْقُوبَ بْنَ عَبْدِ اللَّهِ، حَدَّثَهُ أَنَّهُ، سَمِعَ بُسْرَ بْنَ سَعِيدٍ، يَقُولُ سَمِعْتُ سَعْدَ بْنَ أَبِي وَقَّاصٍ، يَقُولُ سَمِعْتُ خَوْلَةَ بِنْتَ حَكِيمٍ السُّلَمِيَّةَ، تَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنْ نَزَلَ مَنْزِلاً ثُمَّ قَالَ أَعُوذُ بِكَلِمَاتِ اللَّهِ التَّامَّاتِ مِنْ شَرِّ مَا خَلَقَ ‏.‏ لَمْ يَضُرُّهُ شَىْءٌ حَتَّى يَرْتَحِلَ مِنْ مَنْزِلِهِ ذَلِكَ ‏"‏ ‏.‏\hadithno{6878}\hadithtrans{Khaula bint Hakim Sulamiyya reported:I heard Allah's Messenger (ﷺ) as saying: When anyone lands at a place, and then says:" I seek refuge in the Perfect Word of Allah from the evil of what He has created," nothing would harm him until he marches from that stopping place}}
\hadithdefcmd{muslim}{6880}{وَحَدَّثَنَا هَارُونُ بْنُ مَعْرُوفٍ، وَأَبُو الطَّاهِرِ، كِلاَهُمَا عَنِ ابْنِ وَهْبٍ، - وَاللَّفْظُ لِهَارُونَ - حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، قَالَ وَأَخْبَرَنَا عَمْرٌو، - وَهُوَ ابْنُ الْحَارِثِ - أَنَّ يَزِيدَ بْنَ أَبِي، حَبِيبٍ وَالْحَارِثَ بْنَ يَعْقُوبَ حَدَّثَاهُ عَنْ يَعْقُوبَ بْنِ عَبْدِ اللَّهِ بْنِ الأَشَجِّ، عَنْ بُسْرِ بْنِ سَعِيدٍ، عَنْ سَعْدِ بْنِ أَبِي وَقَّاصٍ، عَنْ خَوْلَةَ بِنْتِ حَكِيمٍ السُّلَمِيَّةِ، أَنَّهَا سَمِعَتْ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ إِذَا نَزَلَ أَحَدُكُمْ مَنْزِلاً فَلْيَقُلْ أَعُوذُ بِكَلِمَاتِ اللَّهِ التَّامَّاتِ مِنْ شَرِّ مَا خَلَقَ ‏.‏ فَإِنَّهُ لاَ يَضُرُّهُ شَىْءٌ حَتَّى يَرْتَحِلَ مِنْهُ ‏"‏ ‏.‏ قَالَ يَعْقُوبُ وَقَالَ الْقَعْقَاعُ بْنُ حَكِيمٍ عَنْ ذَكْوَانَ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّهُ قَالَ جَاءَ رَجُلٌ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ مَا لَقِيتُ مِنْ عَقْرَبٍ لَدَغَتْنِي الْبَارِحَةَ قَالَ ‏"‏ أَمَا لَوْ قُلْتَ حِينَ أَمْسَيْتَ أَعُوذُ بِكَلِمَاتِ اللَّهِ التَّامَّاتِ مِنْ شَرِّ مَا خَلَقَ لَمْ تَضُرُّكَ ‏"‏ ‏.‏\hadithno{6880}\hadithtrans{Khaula bint Hakim Sulamiyya reported:I heard Allah's Messenger (ﷺ) as saying: When any one of you stays at a place, he should say:" I seek refuge in the Perfect Word of Allah from the evil of that He created." Nothing would then do him any harm until he moves from that place. Abu Huraira reported that a person came to Allah's Messenger (ﷺ) and said:" Allah's Messenger, I was stung by a scorpion during the night. Thereupon he said: Had you recited these words in the evening:" I seek refuge in the Perfect Word of Allah from the evil of what He created," it would not have done any harm to you}}
\hadithdefcmd{muslim}{6881}{وَحَدَّثَنِي عِيسَى بْنُ حَمَّادٍ الْمِصْرِيُّ، أَخْبَرَنِي اللَّيْثُ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ جَعْفَرٍ، عَنْ يَعْقُوبَ، أَنَّهُ ذَكَرَ لَهُ أَنَّ أَبَا صَالِحٍ، مَوْلَى غَطَفَانَ أَخْبَرَهُ أَنَّهُ، سَمِعَ أَبَا هُرَيْرَةَ، يَقُولُ قَالَ رَجُلٌ يَا رَسُولَ اللَّهِ لَدَغَتْنِي عَقْرَبٌ ‏.‏ بِمِثْلِ حَدِيثِ ابْنِ وَهْبٍ ‏.‏\hadithno{6881}\hadithtrans{This hadith has been transmitted on the authority of Abu Huraira with a slight variation of wording}}
\hadithdefcmd{muslim}{6882}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، - وَاللَّفْظُ لِعُثْمَانَ - قَالَ إِسْحَاقُ أَخْبَرَنَا وَقَالَ، عُثْمَانُ حَدَّثَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ سَعْدِ بْنِ عُبَيْدَةَ، حَدَّثَنِي الْبَرَاءُ بْنُ عَازِبٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ إِذَا أَخَذْتَ مَضْجَعَكَ فَتَوَضَّأْ وُضُوءَكَ لِلصَّلاَةِ ثُمَّ اضْطَجِعْ عَلَى شِقِّكَ الأَيْمَنِ ثُمَّ قُلِ اللَّهُمَّ إِنِّي أَسْلَمْتُ وَجْهِي إِلَيْكَ وَفَوَّضْتُ أَمْرِي إِلَيْكَ وَأَلْجَأْتُ ظَهْرِي إِلَيْكَ رَغْبَةً وَرَهْبَةً إِلَيْكَ لاَ مَلْجَأَ وَلاَ مَنْجَا مِنْكَ إِلاَّ إِلَيْكَ آمَنْتُ بِكِتَابِكَ الَّذِي أَنْزَلْتَ وَبِنَبِيِّكَ الَّذِي أَرْسَلْتَ وَاجْعَلْهُنَّ مِنْ آخِرِ كَلاَمِكَ فَإِنْ مُتَّ مِنْ لَيْلَتِكَ مُتَّ وَأَنْتَ عَلَى الْفِطْرَةِ ‏"‏ ‏.‏ قَالَ فَرَدَّدْتُهُنَّ لأَسْتَذْكِرَهُنَّ فَقُلْتُ آمَنْتُ بِرَسُولِكَ الَّذِي أَرْسَلْتَ قَالَ ‏"‏ قُلْ آمَنْتُ بِنَبِيِّكَ الَّذِي أَرْسَلْتَ ‏"‏ ‏.‏\hadithno{6882}\hadithtrans{Al-Bara' b. 'Azib reported that Allah's, Messenger (may peace be upon said:When you go to bed, perform ablution as is done for prayer; then lie down pn the right side and recite:" O Allah, I turn my face towards Thee and entrust my affair to Thee. I retreat unto Thee for protection with hope in Thee and fear of Thee. There is no resort and no deliverer (from hardship) but Thou only. I affirm my faith in Thine books which Thou revealed and in Thine Apostles whom Thou sent." Make this as the last word of yours (when you go to sleep) and in case you die during that night, you would die upon Fitra (upon Islam). And as I repeated these words in order to commit them to memory, I said:" I affirm my faith in Thy Messenger (Rasul) whom Thou sent." He said: Say:" I affirm my faith in the Apostle (Nabi) whom Thou sent}}
\hadithdefcmd{muslim}{6883}{وَحَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا عَبْدُ اللَّهِ، - يَعْنِي ابْنَ إِدْرِيسَ - قَالَ سَمِعْتُ حُصَيْنًا، عَنْ سَعْدِ بْنِ عُبَيْدَةَ، عَنِ الْبَرَاءِ بْنِ عَازِبٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ بِهَذَا الْحَدِيثِ غَيْرَ أَنَّ مَنْصُورًا أَتَمُّ حَدِيثًا وَزَادَ فِي حَدِيثِ حُصَيْنٍ ‏ "‏ وَإِنْ أَصْبَحَ أَصَابَ خَيْرًا ‏"‏ ‏.‏\hadithno{6883}\hadithtrans{This hadith has been transmitted on the authority of al-Bara' b. 'Azib with a slight variation of wording and there is this addition in the hadith transmitted on the authority of Husain:" In case you get up in the morning, you will get up with bliss}}
\hadithdefcmd{muslim}{6884}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا أَبُو دَاوُدَ، حَدَّثَنَا شُعْبَةُ، ح وَحَدَّثَنَا ابْنُ بَشَّارٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ، وَأَبُو دَاوُدَ قَالاَ حَدَّثَنَا شُعْبَةُ، عَنْ عَمْرِو بْنِ مُرَّةَ، قَالَ سَمِعْتُ سَعْدَ بْنَ عُبَيْدَةَ، يُحَدِّثُ عَنِ الْبَرَاءِ بْنِ عَازِبٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَمَرَ رَجُلاً إِذَا أَخَذَ مَضْجَعَهُ مِنَ اللَّيْلِ أَنْ يَقُولَ ‏ "‏ اللَّهُمَّ أَسْلَمْتُ نَفْسِي إِلَيْكَ وَوَجَّهْتُ وَجْهِي إِلَيْكَ وَأَلْجَأْتُ ظَهْرِي إِلَيْكَ وَفَوَّضْتُ أَمْرِي إِلَيْكَ رَغْبَةً وَرَهْبَةً إِلَيْكَ لاَ مَلْجَأَ وَلاَ مَنْجَا مِنْكَ إِلاَّ إِلَيْكَ آمَنْتُ بِكِتَابِكَ الَّذِي أَنْزَلْتَ وَبِرَسُولِكَ الَّذِي أَرْسَلْتَ ‏.‏ فَإِنْ مَاتَ مَاتَ عَلَى الْفِطْرَةِ ‏"‏ ‏.‏ وَلَمْ يَذْكُرِ ابْنُ بَشَّارٍ فِي حَدِيثِهِ مِنَ اللَّيْلِ ‏.‏\hadithno{6884}\hadithtrans{Al-Bara' b. 'Azib reported that Allah's Messenger (in may peace be upon him) commanded a person (in these words):When you go to bed during night, you should say:" O Allah, I surrender myself to Thee and entrust my affair to Thee, with hope in Thee and fear of Thee. There is no resort and no deliverer (from hardship but Thou). I affirm my faith in the Book which Thou revealed and in the Messengers whom Thou sent." If you die in this state you would die on Fitra, and Ibn Bashshdr did not make a mention of" night" in this hadith}}
\hadithdefcmd{muslim}{6885}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا أَبُو الأَحْوَصِ، عَنْ أَبِي إِسْحَاقَ، عَنِ الْبَرَاءِ بْنِ، عَازِبٍ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم لِرَجُلٍ ‏"‏ يَا فُلاَنُ إِذَا أَوَيْتَ إِلَى فِرَاشِكَ ‏"‏ ‏.‏ بِمِثْلِ حَدِيثِ عَمْرِو بْنِ مُرَّةَ غَيْرَ أَنَّهُ قَالَ ‏"‏ وَبِنَبِيِّكَ الَّذِي أَرْسَلْتَ ‏.‏ فَإِنْ مُتَّ مِنْ لَيْلَتِكَ مُتَّ عَلَى الْفِطْرَةِ وَإِنْ أَصْبَحْتَ أَصَبْتَ خَيْرًا ‏"‏ ‏.‏\hadithno{6885}\hadithtrans{This hadith has been transmitted on the authority of al-Bara' b. 'Azib that Allah's Messenger (ﷺ) said to a person:O, so and so, as you go to your bed; the rest of the hadith is the same but with this variation of wording that he said:" Thine Apostle whom Thou sent." If you die that night you would die on Fitra and if you get up in the morning you would get up with a bliss}}
\hadithdefcmd{muslim}{6886}{حَدَّثَنَا ابْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي، إِسْحَاقَ أَنَّهُ سَمِعَ الْبَرَاءَ بْنَ عَازِبٍ، يَقُولُ أَمَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم رَجُلاً ‏.‏ بِمِثْلِهِ وَلَمْ يَذْكُرْ ‏ "‏ وَإِنْ أَصْبَحْتَ أَصَبْتَ خَيْرًا ‏"‏ ‏.‏\hadithno{6886}\hadithtrans{This hadith has been transmitted on the authority of al-Bara' b. 'Azib that Allah's Messenger (ﷺ) commanded a person (in these words) and there is no mention of this:" if you get up in the morning you would get up with a bliss}}
\hadithdefcmd{muslim}{6887}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا شُعْبَةُ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي السَّفَرِ، عَنْ أَبِي بَكْرِ بْنِ أَبِي مُوسَى، عَنِ الْبَرَاءِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ إِذَا أَخَذَ مَضْجَعَهُ قَالَ ‏"‏ اللَّهُمَّ بِاسْمِكَ أَحْيَا وَبِاسْمِكَ أَمُوتُ ‏"‏ ‏.‏ وَإِذَا اسْتَيْقَظَ قَالَ ‏"‏ الْحَمْدُ لِلَّهِ الَّذِي أَحْيَانَا بَعْدَ مَا أَمَاتَنَا وَإِلَيْهِ النُّشُورُ ‏"‏ ‏.‏\hadithno{6887}\hadithtrans{Al-Bara' reported that whenever Allah's Messenger (ﷺ) went to bed, he said:" O Allah, it is with Thine Name that I live and it is with Thine Name that I die." And when he got up he used to say:" Praise is due to Allah, Who gave us life after our death (sleep) and unto Thee is resurrection}}
\hadithdefcmd{muslim}{6888}{حَدَّثَنَا عُقْبَةُ بْنُ مُكْرَمٍ الْعَمِّيُّ، وَأَبُو بَكْرِ بْنُ نَافِعٍ قَالاَ حَدَّثَنَا غُنْدَرٌ، حَدَّثَنَا شُعْبَةُ، عَنْ خَالِدٍ، قَالَ سَمِعْتُ عَبْدَ اللَّهِ بْنَ الْحَارِثِ، يُحَدِّثُ عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّهُ أَمَرَ رَجُلاً إِذَا أَخَذَ مَضْجَعَهُ قَالَ ‏ "‏ اللَّهُمَّ خَلَقْتَ نَفْسِي وَأَنْتَ تَوَفَّاهَا لَكَ مَمَاتُهَا وَمَحْيَاهَا إِنْ أَحْيَيْتَهَا فَاحْفَظْهَا وَإِنْ أَمَتَّهَا فَاغْفِرْ لَهَا اللَّهُمَّ إِنِّي أَسْأَلُكَ الْعَافِيَةَ ‏"‏ ‏.‏ فَقَالَ لَهُ رَجُلٌ أَسَمِعْتَ هَذَا مِنْ عُمَرَ فَقَالَ مِنْ خَيْرٍ مِنْ عُمَرَ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ قَالَ ابْنُ نَافِعٍ فِي رِوَايَتِهِ عَنْ عَبْدِ اللَّهِ بْنِ الْحَارِثِ ‏.‏ وَلَمْ يَذْكُرْ سَمِعْتُ ‏.‏\hadithno{6888}\hadithtrans{Abdullah b. 'Umar commanded a person that as he went to bed, he should say:" O Allah, Thou created my being and it is for Thee to take it to its ultimate goal. And its death and life is due to Thee, and if Thou givest it life, safeguard it; and if Thou bringst death, grant it pardon. O Allah, I beg of Thee safety." A person said to him: Did you hear it from Umar? Thereupon he said: (I have heard from one) who is better than Umar, viz. from Allah's Messenger (ﷺ). Ibn Nafi, reported this on the authority of Abdullah b. Harith but he did not make mention of this" that he heard it himself}}
\hadithdefcmd{muslim}{6889}{حَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا جَرِيرٌ، عَنْ سُهَيْلٍ، قَالَ كَانَ أَبُو صَالِحٍ يَأْمُرُنَا إِذَا أَرَادَ أَحَدُنَا أَنْ يَنَامَ أَنْ يَضْطَجِعَ عَلَى شِقِّهِ الأَيْمَنِ ثُمَّ يَقُولُ ‏ "‏ اللَّهُمَّ رَبَّ السَّمَوَاتِ وَرَبَّ الأَرْضِ وَرَبَّ الْعَرْشِ الْعَظِيمِ رَبَّنَا وَرَبَّ كُلِّ شَىْءٍ فَالِقَ الْحَبِّ وَالنَّوَى وَمُنْزِلَ التَّوْرَاةِ وَالإِنْجِيلِ وَالْفُرْقَانِ أَعُوذُ بِكَ مِنْ شَرِّ كُلِّ شَىْءٍ أَنْتَ آخِذٌ بِنَاصِيَتِهِ اللَّهُمَّ أَنْتَ الأَوَّلُ فَلَيْسَ قَبْلَكَ شَىْءٌ وَأَنْتَ الآخِرُ فَلَيْسَ بَعْدَكَ شَىْءٌ وَأَنْتَ الظَّاهِرُ فَلَيْسَ فَوْقَكَ شَىْءٌ وَأَنْتَ الْبَاطِنُ فَلَيْسَ دُونَكَ شَىْءٌ اقْضِ عَنَّا الدَّيْنَ وَأَغْنِنَا مِنَ الْفَقْرِ ‏"‏ ‏.‏ وَكَانَ يَرْوِي ذَلِكَ عَنْ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{6889}\hadithtrans{Suhail reported that Abu Salih used to command us (in these words):When any one of you intends to go to sleep, he should lie on the bed on his right side and then say:" O Allah. the Lord of the Heavens and the Lord of the Earth and Lord of the Magnificent Throne, our Lord, and the Lord of evervthina, the Splitter of the grain of corn and the datestone (or fruit kernal), the Revealer of Torah and Injil (Bible) and Criterion (the Holy Qur'an), I seek refuge in Thee from the evil of every- thing Thou art to sieze by the forelock (Thou hast perfect control over it). O Allah, Thou art the First, there is naught before Thee, and Thou art the Last and there is naught after Thee, and Thou art Evident and there is nothing above Thee, and Thou art Innermost and there is nothing beyond Thee. Remove the burden of debt from us and relieve us from want." Abu Salih used to narrate it from Abu Huraira who narrated it from Allah's Apostle (ﷺ)}}
\hadithdefcmd{muslim}{6890}{وَحَدَّثَنِي عَبْدُ الْحَمِيدِ بْنُ بَيَانٍ الْوَاسِطِيُّ، حَدَّثَنَا خَالِدٌ، - يَعْنِي الطَّحَّانَ - عَنْ سُهَيْلٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَأْمُرُنَا إِذَا أَخَذْنَا مَضْجَعَنَا أَنْ نَقُولَ ‏.‏ بِمِثْلِ حَدِيثِ جَرِيرٍ وَقَالَ ‏ "‏ مِنْ شَرِّ كُلِّ دَابَّةٍ أَنْتَ آخِذٌ بِنَاصِيَتِهَا ‏"‏ ‏.‏\hadithno{6890}\hadithtrans{Abu Huraira reported that Allah's Messenger (ﷺ) used to command us that as we go to our bedo, we should utter the words (as mention- ed above) and he also said (these words):" From the evil of every animal, Thou hast hold upon its forelock (Thou bast full control over it)}}
\hadithdefcmd{muslim}{6891}{وَحَدَّثَنَا أَبُو كُرَيْبٍ، مُحَمَّدُ بْنُ الْعَلاَءِ حَدَّثَنَا أَبُو أُسَامَةَ، ح وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي، شَيْبَةَ وَأَبُو كُرَيْبٍ قَالاَ حَدَّثَنَا ابْنُ أَبِي عُبَيْدَةَ، حَدَّثَنَا أَبِي كِلاَهُمَا، عَنِ الأَعْمَشِ، عَنْ أَبِي، صَالِحٍ عَنْ أَبِي هُرَيْرَةَ، قَالَ أَتَتْ فَاطِمَةُ النَّبِيَّ صلى الله عليه وسلم تَسْأَلُهُ خَادِمًا فَقَالَ لَهَا ‏ "‏ قُولِي اللَّهُمَّ رَبَّ السَّمَوَاتِ السَّبْعِ ‏"‏ ‏.‏ بِمِثْلِ حَدِيثِ سُهَيْلٍ عَنْ أَبِيهِ ‏.‏\hadithno{6891}\hadithtrans{Abu Huraira reported that Fatima (the daughter of the Holy Prophet) came to Allah's Apostle (ﷺ) and asked for a servant. He said to her:Say:" O Allah, the Lord of the seven heavens" ; the rest of the hadith is the same}}
\hadithdefcmd{muslim}{6892}{وَحَدَّثَنَا إِسْحَاقُ بْنُ مُوسَى الأَنْصَارِيُّ، حَدَّثَنَا أَنَسُ بْنُ عِيَاضٍ، حَدَّثَنَا عُبَيْدُ اللَّهِ، حَدَّثَنِي سَعِيدُ بْنُ أَبِي سَعِيدٍ الْمَقْبُرِيُّ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا أَوَى أَحَدُكُمْ إِلَى فِرَاشِهِ فَلْيَأْخُذْ دَاخِلَةَ إِزَارِهِ فَلْيَنْفُضْ بِهَا فِرَاشَهُ وَلْيُسَمِّ اللَّهَ فَإِنَّهُ لاَ يَعْلَمُ مَا خَلَفَهُ بَعْدَهُ عَلَى فِرَاشِهِ فَإِذَا أَرَادَ أَنْ يَضْطَجِعَ فَلْيَضْطَجِعْ عَلَى شِقِّهِ الأَيْمَنِ وَلْيَقُلْ سُبْحَانَكَ اللَّهُمَّ رَبِّي بِكَ وَضَعْتُ جَنْبِي وَبِكَ أَرْفَعُهُ إِنْ أَمْسَكْتَ نَفْسِي فَاغْفِرْ لَهَا وَإِنْ أَرْسَلْتَهَا فَاحْفَظْهَا بِمَا تَحْفَظُ بِهِ عِبَادَكَ الصَّالِحِينَ ‏"‏ ‏.‏\hadithno{6892}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as say- ing:When any one of you goes to bed, he should take hold of the hem of his lower garment and then should clean (his bed) with the help of that and then should recite the name of Allah for he himself does tiot know what he left behind him on his bed, and when he intends to lie on bed, he should lie on his right side and utter these words:" Hallowed be Allah, my Lord. It is with Thine (grace) that I place my side (upon the bed) and it is with Thee that I take it up (after sleep), and in case Thou withholdst my being (if thou causest me to die), then grant pardon to my being, and if Thou keepst (this process of breathing on), then protect it with that with which Thou protected Thine pious servants}}
\hadithdefcmd{muslim}{6893}{وَحَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا عَبْدَةُ، عَنْ عُبَيْدِ اللَّهِ بْنِ عُمَرَ، بِهَذَا الإِسْنَادِ وَقَالَ ‏ "‏ ثُمَّ لْيَقُلْ بِاسْمِكَ رَبِّي وَضَعْتُ جَنْبِي فَإِنْ أَحْيَيْتَ نَفْسِي فَارْحَمْهَا ‏"‏ ‏.‏\hadithno{6893}\hadithtrans{This hadith has been narrated on the authority of Ubaidullah b. Umar with the same chain of transmitters and he said:Then utter:" My Lord. with Thine name I place my side and if Thou keepest me alive have mercy upon myself}}
\hadithdefcmd{muslim}{6894}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، عَنْ حَمَّادِ بْنِ سَلَمَةَ، عَنْ ثَابِتٍ، عَنْ أَنَسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ إِذَا أَوَى إِلَى فِرَاشِهِ قَالَ ‏ "‏ الْحَمْدُ لِلَّهِ الَّذِي أَطْعَمَنَا وَسَقَانَا وَكَفَانَا وَآوَانَا فَكَمْ مِمَّنْ لاَ كَافِيَ لَهُ وَلاَ مُئْوِيَ ‏"‏ ‏.‏\hadithno{6894}\hadithtrans{Anas reported Allah's Messenger (ﷺ) as saying:When you go to bed, say:" Praise is due to Allah Who fed us, provided us drink, sufficed us and provided us with shelter, for many a people there is none to suffice and none to provide shelter}}
\hadithdefcmd{muslim}{6895}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، - وَاللَّفْظُ لِيَحْيَى - قَالاَ أَخْبَرَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ هِلاَلٍ، عَنْ فَرْوَةَ بْنِ نَوْفَلٍ الأَشْجَعِيِّ، قَالَ سَأَلْتُ عَائِشَةَ عَمَّا كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَدْعُو بِهِ اللَّهَ قَالَتْ كَانَ يَقُولُ ‏ "‏ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنْ شَرِّ مَا عَمِلْتُ وَمِنْ شَرِّ مَا لَمْ أَعْمَلْ ‏"‏ ‏.‏\hadithno{6895}\hadithtrans{Farwa' b. Naufal Ashja'i reported:I asked: 'A'isha, in what words did Allah's Messenger (ﷺ) supplicate Allah? She said that he used to utter:" I seek refuge in Thee from the evil of what I did and from the evil of what I did not}}
\hadithdefcmd{muslim}{6896}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو كُرَيْبٍ قَالاَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ إِدْرِيسَ، عَنْ حُصَيْنٍ، عَنْ هِلاَلٍ، عَنْ فَرْوَةَ بْنِ نَوْفَلٍ، قَالَ سَأَلْتُ عَائِشَةَ عَنْ دُعَاءٍ، كَانَ يَدْعُو بِهِ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَتْ كَانَ يَقُولُ ‏ "‏ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنْ شَرِّ مَا عَمِلْتُ وَشَرِّ مَا لَمْ أَعْمَلْ ‏"‏ ‏.‏\hadithno{6896}\hadithtrans{Farwa' b. Naufal reported:I asked 'A'isha about the supplication that Allah's Messenger (ﷺ) made. She said that he used to say:" O Allah, I seek refuge in Thee from the evil of what I have done and from the evil of what I have not done}}
\hadithdefcmd{muslim}{6897}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالاَ حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، ح وَحَدَّثَنَا مُحَمَّدُ، بْنُ عَمْرِو بْنِ جَبَلَةَ حَدَّثَنَا مُحَمَّدٌ، - يَعْنِي ابْنَ جَعْفَرٍ - كِلاَهُمَا عَنْ شُعْبَةَ، عَنْ حُصَيْنٍ، بِهَذَا الإِسْنَادِ مِثْلَهُ غَيْرَ أَنَّ فِي حَدِيثِ مُحَمَّدِ بْنِ جَعْفَرٍ ‏ "‏ وَمِنْ شَرِّ مَا لَمْ أَعْمَلْ ‏"‏ ‏.‏\hadithno{6897}\hadithtrans{This hadith has been narrated on the authority of Muhammad b. ja'far through another chain of transmitters}}
\hadithdefcmd{muslim}{6898}{وَحَدَّثَنِي عَبْدُ اللَّهِ بْنُ هَاشِمٍ، حَدَّثَنَا وَكِيعٌ، عَنِ الأَوْزَاعِيِّ، عَنْ عَبْدَةَ بْنِ أَبِي لُبَابَةَ، عَنْ هِلاَلِ بْنِ يَسَافٍ، عَنْ فَرْوَةَ بْنِ نَوْفَلٍ، عَنْ عَائِشَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَقُولُ فِي دُعَائِهِ ‏ "‏ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنْ شَرِّ مَا عَمِلْتُ وَشَرِّ مَا لَمْ أَعْمَلْ ‏"‏ ‏.‏\hadithno{6898}\hadithtrans{Farwa' b. Naufal reported on the authority of 'A'isha that Allah's Mes- senger (ﷺ) used to supplicate (in these words):" O Allah, I seek refuge in Thee from the evil of what I did and from the evil of what I did not}}
\hadithdefcmd{muslim}{6899}{حَدَّثَنِي حَجَّاجُ بْنُ الشَّاعِرِ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَمْرٍو أَبُو مَعْمَرٍ، حَدَّثَنَا عَبْدُ الْوَارِثِ، حَدَّثَنَا الْحُسَيْنُ، حَدَّثَنِي ابْنُ بُرَيْدَةَ، عَنْ يَحْيَى بْنِ يَعْمُرَ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَقُولُ ‏ "‏ اللَّهُمَّ لَكَ أَسْلَمْتُ وَبِكَ آمَنْتُ وَعَلَيْكَ تَوَكَّلْتُ وَإِلَيْكَ أَنَبْتُ وَبِكَ خَاصَمْتُ اللَّهُمَّ إِنِّي أَعُوذُ بِعِزَّتِكَ لاَ إِلَهَ إِلاَّ أَنْتَ أَنْ تُضِلَّنِي أَنْتَ الْحَىُّ الَّذِي لاَ يَمُوتُ وَالْجِنُّ وَالإِنْسُ يَمُوتُونَ ‏"‏ ‏.‏\hadithno{6899}\hadithtrans{Ibn 'Abbas reported that Allah's Messenger (ﷺ) used to say:" O Allah, it is unto Thee that I surrender myself. I affirm my faith in Thee and repose my trust in Thee and turn to Thee in repentance and with Thy help fought my adversaries. O Allah, I seek refuge in Thee with Thine Power; there is no god but Thou, lest Thou leadest me astray. Thou art ever-living that dieth not, while the Jinn and mankind die}}
\hadithdefcmd{muslim}{6900}{حَدَّثَنِي أَبُو الطَّاهِرِ، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَخْبَرَنِي سُلَيْمَانُ بْنُ بِلاَلٍ، عَنْ سُهَيْلِ، بْنِ أَبِي صَالِحٍ عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ إِذَا كَانَ فِي سَفَرٍ وَأَسْحَرَ يَقُولُ ‏ "‏ سَمَّعَ سَامِعٌ بِحَمْدِ اللَّهِ وَحُسْنِ بَلاَئِهِ عَلَيْنَا رَبَّنَا صَاحِبْنَا وَأَفْضِلْ عَلَيْنَا عَائِذًا بِاللَّهِ مِنَ النَّارِ ‏"‏ ‏.‏\hadithno{6900}\hadithtrans{Abu Huraira reported that when Allah's Messenger (ﷺ) set out on a journey in the morning, he used to say:" A listener listened to our praising Allah (for) His goodly trial of us. Our Lord! acompany us, guard us and bestow upon us Thy grace. I am seeker of refuge in Allah from the Fire}}
\hadithdefcmd{muslim}{6901}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ الْعَنْبَرِيُّ، حَدَّثَنَا أَبِي، حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي إِسْحَاقَ، عَنْ أَبِي بُرْدَةَ بْنِ أَبِي مُوسَى الأَشْعَرِيِّ، عَنْ أَبِيهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ كَانَ يَدْعُو بِهَذَا الدُّعَاءِ ‏ "‏ اللَّهُمَّ اغْفِرْ لِي خَطِيئَتِي وَجَهْلِي وَإِسْرَافِي فِي أَمْرِي وَمَا أَنْتَ أَعْلَمُ بِهِ مِنِّي اللَّهُمَّ اغْفِرْ لِي جِدِّي وَهَزْلِي وَخَطَئِي وَعَمْدِي وَكُلُّ ذَلِكَ عِنْدِي اللَّهُمَّ اغْفِرْ لِي مَا قَدَّمْتُ وَمَا أَخَّرْتُ وَمَا أَسْرَرْتُ وَمَا أَعْلَنْتُ وَمَا أَنْتَ أَعْلَمُ بِهِ مِنِّي أَنْتَ الْمُقَدِّمُ وَأَنْتَ الْمُؤَخِّرُ وَأَنْتَ عَلَى كُلِّ شَىْءٍ قَدِيرٌ ‏"‏ ‏.‏\hadithno{6901}\hadithtrans{Abu Musa Ash'ari reported on the authority of his father that Allahs Apostle (ﷺ) used to supplicate in these words:" O Allah, forgive me my faults, my ignorance, my immoderation in my concerns. And Thou art better aware (of my affairs) than myself. O Allah, grant me forgiveness (of the faults which I committed) seriously or otherwise (and which I committed inadvertently and de- liberately. All these (failings) are in me. O Allah, grant me forgiveness from the fault which I did in haste or deferred, which I committed in privacy or in public and Thou art better aware of (them) than myself. Thou art the First and the Last and over all things Thou art Omnipotent}}
\hadithdefcmd{muslim}{6902}{وَحَدَّثَنَاهُ مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا عَبْدُ الْمَلِكِ بْنُ الصَّبَّاحِ الْمِسْمَعِيُّ، حَدَّثَنَا شُعْبَةُ، فِي هَذَا الإِسْنَادِ ‏.‏\hadithno{6902}\hadithtrans{This hadith has been narrated on the authority of Shu'ba with the same chain of transmitters}}
\hadithdefcmd{muslim}{6903}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ دِينَارٍ، حَدَّثَنَا أَبُو قَطَنٍ، عَمْرُو بْنُ الْهَيْثَمِ الْقُطَعِيُّ عَنْ عَبْدِ الْعَزِيزِ، بْنِ عَبْدِ اللَّهِ بْنِ أَبِي سَلَمَةَ الْمَاجِشُونِ عَنْ قُدَامَةَ بْنِ مُوسَى، عَنْ أَبِي صَالِحٍ السَّمَّانِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ اللَّهُمَّ أَصْلِحْ لِي دِينِيَ الَّذِي هُوَ عِصْمَةُ أَمْرِي وَأَصْلِحْ لِي دُنْيَاىَ الَّتِي فِيهَا مَعَاشِي وَأَصْلِحْ لِي آخِرَتِي الَّتِي فِيهَا مَعَادِي وَاجْعَلِ الْحَيَاةَ زِيَادَةً لِي فِي كُلِّ خَيْرٍ وَاجْعَلِ الْمَوْتَ رَاحَةً لِي مِنْ كُلِّ شَرٍّ ‏"‏ ‏.‏\hadithno{6903}\hadithtrans{Abu Huraira reported that Allah's Messenger (ﷺ) used to supplicate (in these words):" O Allah, set right for me my religion which is the safeguard of my affairs. And set right for me the affairs of my world wherein is my living. And set right for me my Hereafter on which depends my after-life. And make the life for me (a source) of abundance for every good and make my death a source of comfort for me protecting me against every evil}}
\hadithdefcmd{muslim}{6904}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَمُحَمَّدُ بْنُ بَشَّارٍ، قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي إِسْحَاقَ، عَنْ أَبِي الأَحْوَصِ، عَنْ عَبْدِ اللَّهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ كَانَ يَقُولُ ‏ "‏ اللَّهُمَّ إِنِّي أَسْأَلُكَ الْهُدَى وَالتُّقَى وَالْعَفَافَ وَالْغِنَى ‏"‏ ‏.‏\hadithno{6904}\hadithtrans{Abdullah reported that Allah's Messenger (ﷺ) used to supplicate (in these words):" O Allah. I beg of Thee the right guidance, safeguard against evils, chastity and freedom from want}}
\hadithdefcmd{muslim}{6905}{وَحَدَّثَنَا ابْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالاَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ، عَنْ سُفْيَانَ، عَنْ أَبِي، إِسْحَاقَ بِهَذَا الإِسْنَادِ ‏.‏ مِثْلَهُ غَيْرَ أَنَّ ابْنَ الْمُثَنَّى، قَالَ فِي رِوَايَتِهِ ‏ "‏ وَالْعِفَّةَ ‏"‏ ‏.‏\hadithno{6905}\hadithtrans{This hadith has been narrated on the authority of Abu Ishaq with the same chain of transmitters but with a slight variation of wording}}
\hadithdefcmd{muslim}{6906}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَمُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، - وَاللَّفْظُ لاِبْنِ نُمَيْرٍ - قَالَ إِسْحَاقُ أَخْبَرَنَا وَقَالَ الآَخَرَانِ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنْ عَاصِمٍ، عَنْ عَبْدِ اللَّهِ بْنِ الْحَارِثِ، وَعَنْ أَبِي عُثْمَانَ النَّهْدِيِّ، عَنْ زَيْدِ بْنِ أَرْقَمَ، قَالَ لاَ أَقُولُ لَكُمْ إِلاَّ كَمَا كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَقُولُ كَانَ يَقُولُ ‏ "‏ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنَ الْعَجْزِ وَالْكَسَلِ وَالْجُبْنِ وَالْبُخْلِ وَالْهَرَمِ وَعَذَابِ الْقَبْرِ اللَّهُمَّ آتِ نَفْسِي تَقْوَاهَا وَزَكِّهَا أَنْتَ خَيْرُ مَنْ زَكَّاهَا أَنْتَ وَلِيُّهَا وَمَوْلاَهَا اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنْ عِلْمٍ لاَ يَنْفَعُ وَمِنْ قَلْبٍ لاَ يَخْشَعُ وَمِنْ نَفْسٍ لاَ تَشْبَعُ وَمِنْ دَعْوَةٍ لاَ يُسْتَجَابُ لَهَا ‏"‏ ‏.‏\hadithno{6906}\hadithtrans{Zaid b. Alqam reported:I am not going to say anything but only that which Allah's Messenger (may peace be upgn him) used to say. He used to supplicate:" O Allah, I seek refuge in Thee from incapacity, from sloth, from cowardice, from miserliness, decrepitude and from torment of the grave. O Allah, grant to my soul the sense of righteousness and purify it, for Thou art the Best Purifier thereof. Thou art the Protecting Friend thereof, and Guardian thereof. O Allah, I seek refuge in Thee from the knowledge which does not benefit, from the heart that does not entertain the fear (of Allah), from the soul that does not feel contented and the supplication that is not responded}}
\hadithdefcmd{muslim}{6907}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا عَبْدُ الْوَاحِدِ بْنُ زِيَادٍ، عَنِ الْحَسَنِ بْنِ عُبَيْدِ اللَّهِ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ سُوَيْدٍ النَّخَعِيُّ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ يَزِيدَ، عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا أَمْسَى قَالَ ‏"‏ أَمْسَيْنَا وَأَمْسَى الْمُلْكُ لِلَّهِ وَالْحَمْدُ لِلَّهِ لاَ إِلَهَ إِلاَّ اللَّهُ وَحْدَهُ لاَ شَرِيكَ لَهُ ‏"‏ ‏.‏ قَالَ الْحَسَنُ فَحَدَّثَنِي الزُّبَيْدُ أَنَّهُ حَفِظَ عَنْ إِبْرَاهِيمَ فِي هَذَا ‏"‏ لَهُ الْمُلْكُ وَلَهُ الْحَمْدُ وَهُوَ عَلَى كُلِّ شَىْءٍ قَدِيرٌ اللَّهُمَّ أَسْأَلُكَ خَيْرَ هَذِهِ اللَّيْلَةِ وَأَعُوذُ بِكَ مِنْ شَرِّ هَذِهِ اللَّيْلَةِ وَشَرِّ مَا بَعْدَهَا اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنَ الْكَسَلِ وَسُوءِ الْكِبَرِ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنْ عَذَابٍ فِي النَّارِ وَعَذَابٍ فِي الْقَبْرِ ‏"‏ ‏.‏\hadithno{6907}\hadithtrans{Abdullah b. Mas'ud reported that when it was evening Allah's Messenger (ﷺ) used to supplicate:" We entered upon evening and the whole Kingdom of Allah also entered upon evening and praise is due to Allah. There is no god but Allah, the One Who has no partner with Him." Hasan said that Zubaid reported to him that he memorised it from Ibrahim in these very words." His is the Sovereignty and Praise is due to Him, and He is Potent over everything. O Allah, I beg of Thee the good of this night and I seek refuge in Thee from the evil of this night and the evil which follows it. O Allah, I seek refuge in Thee from sloth, from the evil of vanity. O Allah, I seek refuge in Thee from torment in the Hell-Fire and from torment in the grave}}
\hadithdefcmd{muslim}{6908}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا جَرِيرٌ، عَنِ الْحَسَنِ بْنِ عُبَيْدِ اللَّهِ، عَنْ إِبْرَاهِيمَ، بْنِ سُوَيْدٍ عَنْ عَبْدِ الرَّحْمَنِ بْنِ يَزِيدَ، عَنْ عَبْدِ اللَّهِ، قَالَ كَانَ نَبِيُّ اللَّهِ صلى الله عليه وسلم إِذَا أَمْسَى قَالَ ‏"‏ أَمْسَيْنَا وَأَمْسَى الْمُلْكُ لِلَّهِ وَالْحَمْدُ لِلَّهِ لاَ إِلَهَ إِلاَّ اللَّهُ وَحْدَهُ لاَ شَرِيكَ لَهُ ‏"‏ ‏.‏ قَالَ أُرَاهُ قَالَ فِيهِنَّ ‏"‏ لَهُ الْمُلْكُ وَلَهُ الْحَمْدُ وَهُوَ عَلَى كُلِّ شَىْءٍ قَدِيرٌ رَبِّ أَسْأَلُكَ خَيْرَ مَا فِي هَذِهِ اللَّيْلَةِ وَخَيْرَ مَا بَعْدَهَا وَأَعُوذُ بِكَ مِنْ شَرِّ مَا فِي هَذِهِ اللَّيْلَةِ وَشَرِّ مَا بَعْدَهَا رَبِّ أَعُوذُ بِكَ مِنَ الْكَسَلِ وَسُوءِ الْكِبَرِ رَبِّ أَعُوذُ بِكَ مِنْ عَذَابٍ فِي النَّارِ وَعَذَابٍ فِي الْقَبْرِ ‏"‏ ‏.‏ وَإِذَا أَصْبَحَ قَالَ ذَلِكَ أَيْضًا ‏"‏ أَصْبَحْنَا وَأَصْبَحَ الْمُلْكُ لِلَّهِ ‏"‏ ‏.‏\hadithno{6908}\hadithtrans{Abdullah reported that when it was evening Allah's Messenger (ﷺ) used to supplicate:" We have entered upon evening and so, too, the whole Kingdom of Allah has entered upon evening. Praise is due to Allah. There is no god but Allah, the One having no partner with Him." He (the narrator) said: I think that he also uttered (in this supplication these words):" His is tne Sovercignty and to Him is praise due and He is Potent over everything. My Lord, I beg of Thee good that lies in this night and good that follows it and I seek refuge in Thee from the evil that lies in this night and from the evil of that which follows it. My Lord, I seek refuge in Thee from sloth, from the evil of vanity. My Lord, I seek refuge in Thee from torment of the Hell-Fire and from torment of the grave." And when it was morning he said like this:" We entered upon morning and the whole Kingdom of Allah enter ed upon morning}}
\hadithdefcmd{muslim}{6909}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا حُسَيْنُ بْنُ عَلِيٍّ، عَنْ زَائِدَةَ، عَنِ الْحَسَنِ بْنِ، عُبَيْدِ اللَّهِ عَنْ إِبْرَاهِيمَ بْنِ سُوَيْدٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ يَزِيدَ، عَنْ عَبْدِ اللَّهِ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا أَمْسَى قَالَ ‏"‏ أَمْسَيْنَا وَأَمْسَى الْمُلْكُ لِلَّهِ وَالْحَمْدُ لِلَّهِ لاَ إِلَهَ إِلاَّ اللَّهُ وَحْدَهُ لاَ شَرِيكَ لَهُ اللَّهُمَّ إِنِّي أَسْأَلُكَ مِنْ خَيْرِ هَذِهِ اللَّيْلَةِ وَخَيْرِ مَا فِيهَا وَأَعُوذُ بِكَ مِنْ شَرِّهَا وَشَرِّ مَا فِيهَا اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنَ الْكَسَلِ وَالْهَرَمِ وَسُوءِ الْكِبَرِ وَفِتْنَةِ الدُّنْيَا وَعَذَابِ الْقَبْرِ ‏"‏ ‏.‏ قَالَ الْحَسَنُ بْنُ عُبَيْدِ اللَّهِ وَزَادَنِي فِيهِ زُبَيْدٌ عَنْ إِبْرَاهِيمَ بْنِ سُوَيْدٍ عَنْ عَبْدِ الرَّحْمَنِ بْنِ يَزِيدَ عَنْ عَبْدِ اللَّهِ رَفَعَهُ أَنَّهُ قَالَ ‏"‏ لاَ إِلَهَ إِلاَّ اللَّهُ وَحْدَهُ لاَ شَرِيكَ لَهُ لَهُ الْمُلْكُ وَلَهُ الْحَمْدُ وَهُوَ عَلَى كُلِّ شَىْءٍ قَدِيرٌ ‏"‏ ‏.‏\hadithno{6909}\hadithtrans{Abdullah reported that when it was evening Allah's Messenger (ﷺ) used to supplicate:" We have entered upon evening and so has the Kingdom of Allah entere d upon evening; praise is due to Allah, there is no god but Allah the One, and there is no partner with Him. O Allah, I beg of Thee the blessing of this night and the blessing of that which lies in it. I seek refuge in Thee from the evil of it and what lies in it. O Allah, I seek refuge in Thee from sloth, from decrepitude, from the evil of vanity, from trial of the world, and from torment of the grave." Zubaid, through another chain of transmitters, has narrated on the authority of Abdullah directly this addition:" There is no god but Allah, the One, there is no partner with Him, His is the Sovereignty and to Him is praise due and He is Potent over everything}}
\hadithdefcmd{muslim}{6910}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا لَيْثٌ، عَنْ سَعِيدِ بْنِ أَبِي سَعِيدٍ، عَنْ أَبِيهِ، عَنْ أَبِي، هُرَيْرَةَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَقُولُ ‏ "‏ لاَ إِلَهَ إِلاَّ اللَّهُ وَحْدَهُ أَعَزَّ جُنْدَهُ وَنَصَرَ عَبْدَهُ وَغَلَبَ الأَحْزَابَ وَحْدَهُ فَلاَ شَىْءَ بَعْدَهُ ‏"‏ ‏.‏\hadithno{6910}\hadithtrans{This hadith has been transmitted on the authority of Abu Huraira that Allah's Messenge; (ﷺ) used to supplicate thus:" There is no god but Allah, the One Who conferred upon His armies the honour of victory and helped His servant rout the clans; there is nothing after that}}
\hadithdefcmd{muslim}{6911}{حَدَّثَنَا أَبُو كُرَيْبٍ، مُحَمَّدُ بْنُ الْعَلاَءِ حَدَّثَنَا ابْنُ إِدْرِيسَ، قَالَ سَمِعْتُ عَاصِمَ بْنَ كُلَيْبٍ، عَنْ أَبِي بُرْدَةَ، عَنْ عَلِيٍّ، قَالَ قَالَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ قُلِ اللَّهُمَّ اهْدِنِي وَسَدِّدْنِي وَاذْكُرْ بِالْهُدَى هِدَايَتَكَ الطَّرِيقَ وَالسَّدَادِ سَدَادَ السَّهْمِ ‏"‏ ‏.‏\hadithno{6911}\hadithtrans{Ali reported that Allah's Messenger (ﷺ) said to him:Say," O Allah, direct me to the right path and make me adhere to the straight path," and when you make a mention of right guidance, keep in mind the right path and when you consider of the straight (path), keep in mind the straightness of the arrow}}
\hadithdefcmd{muslim}{6912}{وَحَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا عَبْدُ اللَّهِ، - يَعْنِي ابْنَ إِدْرِيسَ - أَخْبَرَنَا عَاصِمُ بْنُ كُلَيْبٍ، بِهَذَا الإِسْنَادِ قَالَ قَالَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ قُلِ اللَّهُمَّ إِنِّي أَسْأَلُكَ الْهُدَى وَالسَّدَادَ ‏"‏ ‏.‏ ثُمَّ ذَكَرَ بِمِثْلِهِ ‏.‏\hadithno{6912}\hadithtrans{This hadith has been narrated on the authority of 'Asim b. Kulaib with the same chain of transmitters that Allah's Messenger (ﷺ) said to me:Say:" O Allah, I beg of Thee righteousness and adhering to the straight path}}
\hadithdefcmd{muslim}{6913}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، وَعَمْرٌو النَّاقِدُ، وَابْنُ أَبِي عُمَرَ، - وَاللَّفْظُ لاِبْنِ أَبِي عُمَرَ - قَالُوا حَدَّثَنَا سُفْيَانُ، عَنْ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ، مَوْلَى آلِ طَلْحَةَ عَنْ كُرَيْبٍ، عَنِ ابْنِ عَبَّاسٍ، عَنْ جُوَيْرِيَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم خَرَجَ مِنْ عِنْدِهَا بُكْرَةً حِينَ صَلَّى الصُّبْحَ وَهِيَ فِي مَسْجِدِهَا ثُمَّ رَجَعَ بَعْدَ أَنْ أَضْحَى وَهِيَ جَالِسَةٌ فَقَالَ ‏"‏ مَا زِلْتِ عَلَى الْحَالِ الَّتِي فَارَقْتُكِ عَلَيْهَا ‏"‏ ‏.‏ قَالَتْ نَعَمْ ‏.‏ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ لَقَدْ قُلْتُ بَعْدَكِ أَرْبَعَ كَلِمَاتٍ ثَلاَثَ مَرَّاتٍ لَوْ وُزِنَتْ بِمَا قُلْتِ مُنْذُ الْيَوْمِ لَوَزَنَتْهُنَّ سُبْحَانَ اللَّهِ وَبِحَمْدِهِ عَدَدَ خَلْقِهِ وَرِضَا نَفْسِهِ وَزِنَةَ عَرْشِهِ وَمِدَادَ كَلِمَاتِهِ ‏"‏ ‏.‏\hadithno{6913}\hadithtrans{Juwairiya reported that Allah's Messenger (ﷺ) came out from (her apartment) in the morning as she was busy in observing her dawn prayer in her place of worship. He came back in the forenoon and she was still sitting there. He (the Holy Prophet) said to her:You have been in the same seat since I left you. She said: Yes. Thereupon Allah's Apostle (ﷺ) said: I recited four words three times after I left you and if these are to be weighed against what you have recited since morning these would outweigh them and (these words) are:" Hallowed be Allah and praise is due to Him according to the number of His creation and according to the pleasure of His Self and according to the weight of His Throne and according to the ink (used in recording) words (for His Praise)}}
\hadithdefcmd{muslim}{6914}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو كُرَيْبٍ وَإِسْحَاقُ عَنْ مُحَمَّدِ بْنِ بِشْرٍ، عَنْ مِسْعَرٍ، عَنْ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي رِشْدِينَ، عَنِ ابْنِ عَبَّاسٍ، عَنْ جُوَيْرِيَةَ، قَالَتْ مَرَّ بِهَا رَسُولُ اللَّهِ صلى الله عليه وسلم حِينَ صَلَّى صَلاَةَ الْغَدَاةِ أَوْ بَعْدَ مَا صَلَّى الْغَدَاةَ ‏.‏ فَذَكَرَ نَحْوَهُ غَيْرَ أَنَّهُ قَالَ ‏ "‏ سُبْحَانَ اللَّهِ عَدَدَ خَلْقِهِ سُبْحَانَ اللَّهِ رِضَا نَفْسِهِ سُبْحَانَ اللَّهِ زِنَةَ عَرْشِهِ سُبْحَانَ اللَّهِ مِدَادَ كَلِمَاتِهِ ‏"‏ ‏.‏\hadithno{6914}\hadithtrans{Juwairiya reported that Allah's Messenger (ﷺ) happened to pass by her as she was observing her dawn prayer; or after she had observed her dawn prayer. The rest of the hadith is the same but with this variation that he said:" Hallowed be Allah according to the number of His creation, hallowed be Allah according to the pleasure of His Self, hallowed be Allah according to the weight of His Throne, hallowed be Allah according to the ink used in recording His words}}
\hadithdefcmd{muslim}{6915}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَمُحَمَّدُ بْنُ بَشَّارٍ، - وَاللَّفْظُ لاِبْنِ الْمُثَنَّى - قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنِ الْحَكَمِ، قَالَ سَمِعْتُ ابْنَ أَبِي لَيْلَى، حَدَّثَنَا عَلِيٌّ، أَنَّ فَاطِمَةَ، اشْتَكَتْ مَا تَلْقَى مِنَ الرَّحَى فِي يَدِهَا وَأَتَى النَّبِيَّ صلى الله عليه وسلم سَبْىٌ فَانْطَلَقَتْ فَلَمْ تَجِدْهُ وَلَقِيَتْ عَائِشَةَ فَأَخْبَرَتْهَا فَلَمَّا جَاءَ النَّبِيُّ صلى الله عليه وسلم أَخْبَرَتْهُ عَائِشَةُ بِمَجِيءِ فَاطِمَةَ إِلَيْهَا فَجَاءَ النَّبِيُّ صلى الله عليه وسلم إِلَيْنَا وَقَدْ أَخَذْنَا مَضَاجِعَنَا فَذَهَبْنَا نَقُومُ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ عَلَى مَكَانِكُمَا ‏"‏ ‏.‏ فَقَعَدَ بَيْنَنَا حَتَّى وَجَدْتُ بَرْدَ قَدَمِهِ عَلَى صَدْرِي ثُمَّ قَالَ ‏"‏ أَلاَ أُعَلِّمُكُمَا خَيْرًا مِمَّا سَأَلْتُمَا إِذَا أَخَذْتُمَا مَضَاجِعَكُمَا أَنْ تُكَبِّرَا اللَّهَ أَرْبَعًا وَثَلاَثِينَ وَتُسَبِّحَاهُ ثَلاَثًا وَثَلاَثِينَ وَتَحْمَدَاهُ ثَلاَثًا وَثَلاَثِينَ فَهُوَ خَيْرٌ لَكُمَا مِنْ خَادِمٍ ‏"‏ ‏.‏\hadithno{6915}\hadithtrans{It is reported on the authority of Ali that Fatima had corns in her hand because of working at the hand-mill. There had fallen to the lot of Allah's Apostle (ﷺ) some prisoners of war. She (Fatima) came to the Prophet (ﷺ) but she did not find him (in the house). She met A'isha and informed her (about her hardship). When Allah's Apostle (ﷺ) came, she (A'isha) informed him about the visit of Fatima. Allah's Messenger (ﷺ) came to them (Fatima and her family). They had gone to their beds. 'Ali further (reported):We tried to stand up (as a mark of respect) but Allah's Messenger (ﷺ) said: Keep to your beds, and he sat amongst us and I felt the coldness of his feet upon my chest. He then said: May I not direct you to something better than what you have asked for? When you go to your bed, you should recite Takbir (Allah-o-Akbar) thirty-four times and Tasbih (Subhan Allah) thirty-three times and Tahmid (al-Hamdu li-Allah) thirty-three times, and that is better than the servant for you}}
\hadithdefcmd{muslim}{6916}{وَحَدَّثَنَاهُ أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، ح وَحَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، حَدَّثَنَا أَبِي ح، وَحَدَّثَنَا ابْنُ الْمُثَنَّى، حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، كُلُّهُمْ عَنْ شُعْبَةَ، بِهَذَا الإِسْنَادِ وَفِي حَدِيثِ مُعَاذٍ ‏ "‏ أَخَذْتُمَا مَضْجَعَكُمَا مِنَ اللَّيْلِ ‏"‏ ‏.‏\hadithno{6916}\hadithtrans{This hadith has been narrated on the authority of Shu'ba with the same chain of transmitters but. with a slight variation of wording}}
\hadithdefcmd{muslim}{6917}{وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ عُبَيْدِ اللَّهِ بْنِ أَبِي يَزِيدَ، عَنْ مُجَاهِدٍ، عَنِ ابْنِ أَبِي لَيْلَى، عَنْ عَلِيِّ بْنِ أَبِي طَالِبٍ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، وَعُبَيْدُ بْنُ يَعِيشَ، عَنْ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا عَبْدُ الْمَلِكِ، عَنْ عَطَاءِ بْنِ أَبِي رَبَاحٍ، عَنْ مُجَاهِدٍ، عَنِ ابْنِ أَبِي لَيْلَى، عَنْ عَلِيٍّ، عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ بِنَحْوِ حَدِيثِ الْحَكَمِ عَنِ ابْنِ أَبِي لَيْلَى، وَزَادَ، فِي الْحَدِيثِ قَالَ عَلِيٌّ مَا تَرَكْتُهُ مُنْذُ سَمِعْتُهُ مِنَ النَّبِيِّ صلى الله عليه وسلم ‏.‏ قِيلَ لَهُ وَلاَ لَيْلَةَ صِفِّينَ قَالَ وَلاَ لَيْلَةَ صِفِّينِ ‏.‏ وَفِي حَدِيثِ عَطَاءٍ عَنْ مُجَاهِدٍ عَنِ ابْنِ أَبِي لَيْلَى قَالَ قُلْتُ لَهُ وَلاَ لَيْلَةَ صِفِّينَ\hadithno{6917}\hadithtrans{This hadith has been transmitted on the authority of Ibn Abi Laili but with this addition:" Ali said: Ever since I heard this (supplication) from Allah's Apostle (ﷺ), I never abandoned it. It was said to him, Not even in the night of Siffin (battle of Siffin)? He sad: Yes, not even in the night of Siffin}}
\hadithdefcmd{muslim}{6920}{حَدَّثَنِي قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا لَيْثٌ، عَنْ جَعْفَرِ بْنِ رَبِيعَةَ، عَنِ الأَعْرَجِ، عَنْ أَبِي، هُرَيْرَةَ أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا سَمِعْتُمْ صِيَاحَ الدِّيَكَةِ فَاسْأَلُوا اللَّهَ مِنْ فَضْلِهِ فَإِنَّهَا رَأَتْ مَلَكًا وَإِذَا سَمِعْتُمْ نَهِيقَ الْحِمَارِ فَتَعَوَّذُوا بِاللَّهِ مِنَ الشَّيْطَانِ فَإِنَّهَا رَأَتْ شَيْطَانًا ‏"‏ ‏.‏\hadithno{6920}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as say- ing. When you listen to the crowing of the cock, ask Allah for His favour as it sees Angels and when you listen to the braying of the donkey, seek refuge in Allah from the Satan for it sees Satan}}
\hadithdefcmd{muslim}{6921}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ وَعُبَيْدُ اللَّهِ بْنُ سَعِيدٍ - وَاللَّفْظُ لاِبْنِ سَعِيدٍ - قَالُوا حَدَّثَنَا مُعَاذُ بْنُ هِشَامٍ، حَدَّثَنِي أَبِي، عَنْ قَتَادَةَ، عَنْ أَبِي الْعَالِيَةِ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ نَبِيَّ اللَّهِ صلى الله عليه وسلم كَانَ يَقُولُ عِنْدَ الْكَرْبِ ‏ "‏ لاَ إِلَهَ إِلاَّ اللَّهُ الْعَظِيمُ الْحَلِيمُ لاَ إِلَهَ إِلاَّ اللَّهُ رَبُّ الْعَرْشِ الْعَظِيمِ لاَ إِلَهَ إِلاَّ اللَّهُ رَبُّ السَّمَوَاتِ وَرَبُّ الأَرْضِ وَرَبُّ الْعَرْشِ الْكَرِيمِ ‏"‏ ‏.‏\hadithno{6921}\hadithtrans{Ibn 'Abbas reported that Allah's Apostle (ﷺ) used to supplicate during the time of trouble (in these words):" There is no god but Allah, the Great, the Tolerant, there is no god but Allah, the Lord of the Magnificent Throne There is no god but Allah, the Lord of the Heaven and the earth, the Lord of the Edifying Throne}}
\hadithdefcmd{muslim}{6922}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، عَنْ هِشَامٍ، بِهَذَا الإِسْنَادِ وَحَدِيثُ مُعَاذِ بْنِ هِشَامٍ أَتَمُّ ‏.‏\hadithno{6922}\hadithtrans{This hadith has been narrated on the authority of Hisham with the same chain of transmitters}}
\hadithdefcmd{muslim}{6923}{وَحَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، أَخْبَرَنَا مُحَمَّدُ بْنُ بِشْرٍ الْعَبْدِيُّ، حَدَّثَنَا سَعِيدُ بْنُ أَبِي عَرُوبَةَ، عَنْ قَتَادَةَ، أَنَّ أَبَا الْعَالِيَةِ الرِّيَاحِيَّ، حَدَّثَهُمْ عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَدْعُو بِهِنَّ وَيَقُولُهُنَّ عِنْدَ الْكَرْبِ فَذَكَرَ بِمِثْلِ حَدِيثِ مُعَاذِ بْنِ هِشَامٍ عَنْ أَبِيهِ عَنْ قَتَادَةَ غَيْرَ أَنَّهُ قَالَ ‏ "‏ رَبُّ السَّمَوَاتِ وَالأَرْضِ ‏"‏ ‏.‏\hadithno{6923}\hadithtrans{Ibn Abbas reported that Allah's Messenger (ﷺ) used to supplicate (with these words) and he (uttered these words) at the time of trouble; the rest of the hadith is the same except with this difference that insted of saying:" The Lord of heaven and the earth," he said:" The Lord of the heaven and that of the earth}}
\hadithdefcmd{muslim}{6924}{وَحَدَّثَنِي مُحَمَّدُ بْنُ حَاتِمٍ، حَدَّثَنَا بَهْزٌ، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، أَخْبَرَنِي يُوسُفُ بْنُ، عَبْدِ اللَّهِ بْنِ الْحَارِثِ عَنْ أَبِي الْعَالِيَةِ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ إِذَا حَزَبَهُ أَمْرٌ قَالَ ‏.‏ فَذَكَرَ بِمِثْلِ حَدِيثِ مُعَاذٍ عَنْ أَبِيهِ وَزَادَ مَعَهُنَّ ‏ "‏ لاَ إِلَهَ إِلاَّ اللَّهُ رَبُّ الْعَرْشِ الْكَرِيمِ ‏"‏ ‏.‏\hadithno{6924}\hadithtrans{Ibn 'Abbas reported this hadith through another chain of transmitters with a sliglit variation of wording}}
\hadithdefcmd{muslim}{6925}{حَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا حَبَّانُ بْنُ هِلاَلٍ، حَدَّثَنَا وُهَيْبٌ، حَدَّثَنَا سَعِيدٌ الْجُرَيْرِيُّ، عَنْ أَبِي عَبْدِ اللَّهِ الْجِسْرِيِّ، عَنِ ابْنِ الصَّامِتِ، عَنْ أَبِي ذَرٍّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم سُئِلَ أَىُّ الْكَلاَمِ أَفْضَلُ قَالَ ‏ "‏ مَا اصْطَفَى اللَّهُ لِمَلاَئِكَتِهِ أَوْ لِعِبَادِهِ سُبْحَانَ اللَّهِ وَبِحَمْدِهِ ‏"‏ ‏.‏\hadithno{6925}\hadithtrans{Abu Dharr reported that Allah's Messenger (ﷺ) was asked as to which words were the best. He said:Those for which Allah made a choice for His Angels and His servants (and the words are):" Hallowed be Allah and praise is due to Him}}
\hadithdefcmd{muslim}{6926}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَحْيَى بْنُ أَبِي بُكَيْرٍ، عَنْ شُعْبَةَ، عَنِ الْجُرَيْرِيِّ، عَنْ أَبِي عَبْدِ اللَّهِ الْجَسْرِيِّ، مِنْ عَنَزَةَ عَنْ عَبْدِ اللَّهِ بْنِ الصَّامِتِ، عَنْ أَبِي ذَرٍّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَلاَ أُخْبِرُكَ بِأَحَبِّ الْكَلاَمِ إِلَى اللَّهِ ‏"‏ ‏.‏ قُلْتُ يَا رَسُولَ اللَّهِ أَخْبِرْنِي بِأَحَبِّ الْكَلاَمِ إِلَى اللَّهِ ‏.‏ فَقَالَ ‏"‏ إِنَّ أَحَبَّ الْكَلاَمِ إِلَى اللَّهِ سُبْحَانَ اللَّهِ وَبِحَمْدِهِ ‏"‏ ‏.‏\hadithno{6926}\hadithtrans{Abu Dharr reported that Allah's Messenger (ﷺ) said:Should I not inform you about the words liked most by Allah? I said: Allah's Mes- senger, do inform me about the words liked most by Allah. He said: Verily, the words liked most by Allah are:" hallowed be Allah and praise is due to Him}}
\hadithdefcmd{muslim}{6927}{حَدَّثَنِي أَحْمَدُ بْنُ عُمَرَ بْنِ حَفْصٍ الْوَكِيعِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ فُضَيْلٍ، حَدَّثَنَا أَبِي، عَنْ طَلْحَةَ بْنِ عُبَيْدِ اللَّهِ بْنِ كَرِيزٍ، عَنْ أُمِّ الدَّرْدَاءِ، عَنْ أَبِي الدَّرْدَاءِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَا مِنْ عَبْدٍ مُسْلِمٍ يَدْعُو لأَخِيهِ بِظَهْرِ الْغَيْبِ إِلاَّ قَالَ الْمَلَكُ وَلَكَ بِمِثْلٍ ‏"‏ ‏.‏\hadithno{6927}\hadithtrans{Abu Dharr reported that Allah's Messenger (ﷺ) said:There is no believing servant who supplicates for his brother behind his back (in his absence) that the Angels do not say: The same be for you too}}
\hadithdefcmd{muslim}{6928}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا النَّضْرُ بْنُ شُمَيْلٍ، حَدَّثَنَا مُوسَى بْنُ سَرْوَانَ، الْمُعَلِّمُ حَدَّثَنِي طَلْحَةُ بْنُ عُبَيْدِ اللَّهِ بْنِ كَرِيزٍ، قَالَ حَدَّثَتْنِي أُمُّ الدَّرْدَاءِ، قَالَتْ حَدَّثَنِي سَيِّدِي، أَنَّهُ سَمِعَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنْ دَعَا لأَخِيهِ بِظَهْرِ الْغَيْبِ قَالَ الْمَلَكُ الْمُوَكَّلُ بِهِ آمِينَ وَلَكَ بِمِثْلٍ ‏"‏ ‏.‏\hadithno{6928}\hadithtrans{Umm Darda' reported:My husband reported that he heard Allah's Mes- senger (ﷺ) as saying: He who supplicates for his brother behind his back (in his absence), the Angel commissioned (for carrying supplication to his Lord) says: Amen, and it is for you also}}
\hadithdefcmd{muslim}{6930}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا عِيسَى بْنُ يُونُسَ، حَدَّثَنَا عَبْدُ الْمَلِكِ بْنُ أَبِي، سُلَيْمَانَ عَنْ أَبِي الزُّبَيْرِ، عَنْ صَفْوَانَ، - وَهُوَ ابْنُ عَبْدِ اللَّهِ بْنِ صَفْوَانَ - وَكَانَتْ تَحْتَهُ الدَّرْدَاءُ قَالَ قَدِمْتُ الشَّامَ فَأَتَيْتُ أَبَا الدَّرْدَاءِ فِي مَنْزِلِهِ فَلَمْ أَجِدْهُ وَوَجَدْتُ أُمَّ الدَّرْدَاءِ فَقَالَتْ أَتُرِيدُ الْحَجَّ الْعَامَ فَقُلْتُ نَعَمْ ‏.‏ قَالَتْ فَادْعُ اللَّهَ لَنَا بِخَيْرٍ فَإِنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَقُولُ ‏ "‏ دَعْوَةُ الْمَرْءِ الْمُسْلِمِ لأَخِيهِ بِظَهْرِ الْغَيْبِ مُسْتَجَابَةٌ عِنْدَ رَأْسِهِ مَلَكٌ مُوَكَّلٌ كُلَّمَا دَعَا لأَخِيهِ بِخَيْرٍ قَالَ الْمَلَكُ الْمُوَكَّلُ بِهِ آمِينَ وَلَكَ بِمِثْلٍ ‏"‏ ‏.‏ قَالَ فَخَرَجْتُ إِلَى السُّوقِ فَلَقِيتُ أَبَا الدَّرْدَاءِ فَقَالَ لِي مِثْلَ ذَلِكَ يَرْوِيهِ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{6930}\hadithtrans{Safwan (and he was Ibn 'Abdullah b. Safwan, and he had been married to Umm Darda') reported:I visited Abu Darda's house in Syria. I did not find him there but Umm Darda' (was present at the house). She said: Do you intend to perform Hajj during this year? I said: Yes. She said: Do supplicate Allah for blessings upon us, for Allah's Apostle (may peace be upon hiin) used to say: The supplication of a Muslim for his brother at his back (in his absence) is responded so long as he makes a supplica- tion for blessings for his brother and the commissioned Angel says: Amen, and says: May it be for you too I I went to the bazar and met Abfi Dardi' and he narrated like this from Allah's Messenger (ﷺ)}}
\hadithdefcmd{muslim}{6931}{وَحَدَّثَنَاهُ أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، عَنْ عَبْدِ الْمَلِكِ بْنِ أَبِي، سُلَيْمَانَ بِهَذَا الإِسْنَادِ مِثْلَهُ وَقَالَ عَنْ صَفْوَانَ بْنِ عَبْدِ اللَّهِ بْنِ صَفْوَانَ، ‏.‏\hadithno{6931}\hadithtrans{This hadith has been narrated on the authority of Safwan b. 'Abdullah b. Safwan with the same chain of transmitters}}
\hadithdefcmd{muslim}{6932}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَابْنُ، نُمَيْرٍ - وَاللَّفْظُ لاِبْنِ نُمَيْرٍ - قَالاَ حَدَّثَنَا أَبُو أُسَامَةَ وَمُحَمَّدُ بْنُ بِشْرٍ عَنْ زَكَرِيَّاءَ بْنِ أَبِي زَائِدَةَ، عَنْ سَعِيدِ بْنِ أَبِي بُرْدَةَ، عَنْ أَنَسِ بْنِ، مَالِكٍ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ اللَّهَ لَيَرْضَى عَنِ الْعَبْدِ أَنْ يَأْكُلَ الأَكْلَةَ فَيَحْمَدَهُ عَلَيْهَا أَوْ يَشْرَبَ الشَّرْبَةَ فَيَحْمَدَهُ عَلَيْهَا ‏"‏ ‏.‏\hadithno{6932}\hadithtrans{Anas b. Malik reported that Allah's Messenger (ﷺ) said:Allah is pleased with His servant who says: Al-Hamdu lillah while taking a morsel of food and while drinking}}
\hadithdefcmd{muslim}{6933}{وَحَدَّثَنِيهِ زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا إِسْحَاقُ بْنُ يُوسُفَ الأَزْرَقُ، حَدَّثَنَا زَكَرِيَّاءُ، بِهَذَا الإِسْنَادِ ‏.‏\hadithno{6933}\hadithtrans{This hadith is reported through Ishaaq bin Yusuf Al-Azraq from Zakariyya bin Abi Za'ida through the same chain}}
\hadithdefcmd{muslim}{6934}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي عُبَيْدٍ، مَوْلَى ابْنِ أَزْهَرَ عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ يُسْتَجَابُ لأَحَدِكُمْ مَا لَمْ يَعْجَلْ فَيَقُولُ قَدْ دَعَوْتُ فَلاَ أَوْ فَلَمْ يُسْتَجَبْ لِي ‏"‏ ‏.‏\hadithno{6934}\hadithtrans{Abu Huraira reported that Allah's Messenger (ﷺ) said:The supplication of every one of you is granted if he does not grow impatient and says: I supplicated but it was not granted}}
\hadithdefcmd{muslim}{6935}{حَدَّثَنِي عَبْدُ الْمَلِكِ بْنُ شُعَيْبِ بْنِ لَيْثٍ، حَدَّثَنِي أَبِي، عَنْ جَدِّي، حَدَّثَنِي عُقَيْلُ بْنُ خَالِدٍ، عَنِ ابْنِ شِهَابٍ، أَنَّهُ قَالَ حَدَّثَنِي أَبُو عُبَيْدٍ، مَوْلَى عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ وَكَانَ مِنَ الْقُرَّاءِ وَأَهْلِ الْفِقْهِ قَالَ سَمِعْتُ أَبَا هُرَيْرَةَ يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يُسْتَجَابُ لأَحَدِكُمْ مَا لَمْ يَعْجَلْ فَيَقُولُ قَدْ دَعَوْتُ رَبِّي فَلَمْ يَسْتَجِبْ لِي ‏"‏ ‏.‏\hadithno{6935}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:The supplication of one of you is granted if he does not grow impatient and say- I supplicated my Lord but it was not granted}}
\hadithdefcmd{muslim}{6936}{حَدَّثَنِي أَبُو الطَّاهِرِ، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي مُعَاوِيَةُ، - وَهُوَ ابْنُ صَالِحٍ - عَنْ رَبِيعَةَ بْنِ يَزِيدَ، عَنْ أَبِي إِدْرِيسَ الْخَوْلاَنِيِّ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ قَالَ ‏"‏ لاَ يَزَالُ يُسْتَجَابُ لِلْعَبْدِ مَا لَمْ يَدْعُ بِإِثْمٍ أَوْ قَطِيعَةِ رَحِمٍ مَا لَمْ يَسْتَعْجِلْ ‏"‏ ‏.‏ قِيلَ يَا رَسُولَ اللَّهِ مَا الاِسْتِعْجَالُ قَالَ ‏"‏ يَقُولُ قَدْ دَعَوْتُ وَقَدْ دَعَوْتُ فَلَمْ أَرَ يَسْتَجِيبُ لِي فَيَسْتَحْسِرُ عِنْدَ ذَلِكَ وَيَدَعُ الدُّعَاءَ ‏"‏ ‏.‏\hadithno{6936}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:The supplication of the servant is granted in case he does not supplicate for sin or for severing the ties of blood, or he does not become impatient. It was said: Allah's Messenger, what does:" If he does not grow impatient" imply? He said: That he should say like this: I supplicated and I supplicated but I did not find it being responded. and theu he becomes frustrated and abandons supplication}}
